ZIM class abstract

Constructors

ZIM()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptFriendApplication(String userID, ZIMFriendApplicationAcceptConfig config) Future<ZIMFriendApplicationAcceptedResult>
todo
acceptGroupInviteApplication(String inviterUserID, String groupID, ZIMGroupInviteApplicationAcceptConfig config) Future<ZIMGroupInviteApplicationAcceptedResult>
todo
acceptGroupJoinApplication(String userID, String groupID, ZIMGroupJoinApplicationAcceptConfig config) Future<ZIMGroupJoinApplicationAcceptedResult>
todo
addFriend(String userID, ZIMFriendAddConfig config) Future<ZIMFriendAddedResult>
todo
addMessageReaction(String reactionType, ZIMMessage message) Future<ZIMMessageReactionAddedResult>
add message reaction
addUsersToBlacklist(List<String> userIDs) Future<ZIMBlacklistUsersAddedResult>
todo
beginRoomAttributesBatchOperation(String roomID, ZIMRoomAttributesBatchOperationConfig config) → void
Open combination room attribute operation.
callAccept(String callID, ZIMCallAcceptConfig config) Future<ZIMCallAcceptanceSentResult>
Supported versions: 2.0.0 and above.
callCancel(List<String> invitees, String callID, ZIMCallCancelConfig config) Future<ZIMCallCancelSentResult>
Supported versions: 2.0.0 and above. Detail description: After the caller initiates a call invitation, the call invitation can be canceled through this interface before the timeout period. Business scenario: When you need to cancel the call invitation initiated before, you can cancel the call invitation through this interface. When to call: It can be called after creating a ZIM instance through create. Note: Canceling the call invitation after the timeout period of the call invitation expires will fail.
callEnd(String callID, ZIMCallEndConfig config) Future<ZIMCallEndSentResult>
Supported versions: 2.9.0 and above. Detail description: End The call in advanced mode. When to call: The call was in advanced mode and the user status was Accepted. Note: User calls that are not in the call will fail. ZupdatIM SDK Does not have service logic after the call ends, and developers can customize the development logic after the end. Related callbacks: ZIMCallEndSentCallback.
callingInvite(List<String> invitees, String callID, ZIMCallingInviteConfig config) Future<ZIMCallingInvitationSentResult>
todo
callInvite(List<String> invitees, ZIMCallInviteConfig config) Future<ZIMCallInvitationSentResult>
Supported versions: 2.0.0 and above. Detail description: When the caller initiates a call invitation, the called party can use callAccept to accept the call invitation or callReject to reject the invitation. Business scenario: When you need to initiate a call invitation, you can create a unique callid through this interface to maintain this call invitation. When to call: It can be called after creating a ZIM instance through create. Note: The call invitation has a timeout period, and the call invitation will end when the timeout period expires.
callJoin(String callID, ZIMCallJoinConfig config) Future<ZIMCallJoinSentResult>
todo
callQuit(String callID, ZIMCallQuitConfig config) Future<ZIMCallQuitSentResult>
Supported versions: 2.9.0 and above. Detail description: When the Lord's call initiates the invitation and is called and accepts it, the current call can be exited through the interface. When to call: It can be called after creating a ZIM instance through create. Note: The callee will fail to quit the uninvited callid. Related callbacks: ZIMCallQuitSentCallback.
callReject(String callID, ZIMCallRejectConfig config) Future<ZIMCallRejectionSentResult>
Supported versions: 2.0.0 and above.
cancelSendingMessage(ZIMMessage message, ZIMSendingMessageCancelConfig config) Future<void>
Cancel sending message.
checkFriendsRelation(List<String> userIDs, ZIMFriendRelationCheckConfig config) Future<ZIMFriendsRelationCheckedResult>
todo
checkUserIsInBlacklist(String userID) Future<ZIMBlacklistCheckedResult>
todo
clearConversationTotalUnreadMessageCount() Future<void>
clear all conversations unreads.
clearConversationUnreadMessageCount(String conversationID, ZIMConversationType conversationType) Future<ZIMConversationUnreadMessageCountClearedResult>
clear session unreads.
clearLocalFileCache(ZIMFileCacheClearConfig config) Future<void>
Clear the local message cache of the current user.
createGroup(ZIMGroupInfo groupInfo, List<String> userIDs, [ZIMGroupAdvancedConfig? config]) Future<ZIMGroupCreatedResult>
Create a group with the andvanced info such as group attributes and group notice.
createRoom(ZIMRoomInfo roomInfo, [ZIMRoomAdvancedConfig? config]) Future<ZIMRoomCreatedResult>
Create a room with advanced settings
deleteAllConversationMessages(ZIMMessageDeleteConfig config) Future<void>
Delete all messages for all conversations.
deleteAllConversations(ZIMConversationDeleteConfig config) Future<void>
delete all conversations.
deleteAllMessage(String conversationID, ZIMConversationType conversationType, ZIMMessageDeleteConfig config) Future<ZIMMessageDeletedResult>
Delete all message.
deleteConversation(String conversationID, ZIMConversationType conversationType, ZIMConversationDeleteConfig config) Future<ZIMConversationDeletedResult>
delete the conversation.
deleteFriends(List<String> userIDs, ZIMFriendDeleteConfig config) Future<ZIMFriendsDeletedResult>
todo
deleteGroupAttributes(List<String> keys, String groupID) Future<ZIMGroupAttributesOperatedResult>
todo
deleteMessageReaction(String reactionType, ZIMMessage message) Future<ZIMMessageReactionDeletedResult>
delete message reaction
deleteMessages(List<ZIMMessage> messageList, String conversationID, ZIMConversationType conversationType, ZIMMessageDeleteConfig config) Future<ZIMMessageDeletedResult>
delete message.
deleteRoomAttributes(List<String> keys, String roomID, ZIMRoomAttributesDeleteConfig config) Future<ZIMRoomAttributesOperatedCallResult>
Delete room attributes.
destroy() → dynamic
Destroy the ZIM instance.
dismissGroup(String groupID) Future<ZIMGroupDismissedResult>
Available since: 2.0.0 and above.
downloadMediaFile(ZIMMessage message, ZIMMediaFileType fileType, ZIMMediaDownloadConfig config, ZIMMediaDownloadingProgress progress) Future<ZIMMediaDownloadedResult>
Download media message content.
editMessage(ZIMMessage message, ZIMMessageEditConfig config, ZIMMessageSendNotification? notification) Future<ZIMMessageEditedResult>
Edit message.
endRoomAttributesBatchOperation(String roomID) Future<ZIMRoomAttributesBatchOperatedResult>
Complete the property operation of the combined room.
enterRoom(ZIMRoomInfo roomInfo, ZIMRoomAdvancedConfig config) Future<ZIMRoomEnteredResult>
Enter the room. If the room does not exist, it will be created automatically.
exportLocalMessages(String folderPath, ZIMMessageExportConfig config, ZIMMessageExportingProgress progress) Future<void>
Example Export the local message of the current user.
importLocalMessages(String folderPath, ZIMMessageImportConfig config, ZIMMessageImportingProgress progress) Future<void>
Import local messages of the current user.
insertMessageToLocalDB(ZIMMessage message, String conversationID, ZIMConversationType conversationType, String senderUserID) Future<ZIMMessageInsertedResult>
Insert a message to the local DB.
inviteUsersIntoGroup(List<String> userIDs, String groupID) Future<ZIMGroupUsersInvitedResult>
Available since: 2.0.0 and above.
joinGroup(String groupID) Future<ZIMGroupJoinedResult>
Available since: 2.0.0 and above.
joinRoom(String roomID) Future<ZIMRoomJoinedResult>
Join a room.
kickGroupMembers(List<String> userIDs, String groupID) Future<ZIMGroupMemberKickedResult>
Available since: 2.0.0 and above. Description: After a user joins a group, you can use this method to remove the user from the group. Use cases: You can use this method to remove one or more users from the group. When to call /Trigger: The ZIM instance can be invoked after being created by create and logged in. Restrictions: You can't kick someone unless you're the leader of the group. Caution: This interface does not require the peer's consent or the peer's online status. It cannot accept group-related callbacks after being kicked out. History messages and sessions remain after being kicked out and can still enter the group. Related callbacks: Through the callback ZIMGroupMemberKickedCallback can get the user kicked out the results of the group. Related APIs: You can invite a target user into a group through inviteUsersIntoGroup.
leaveAllRoom() Future<ZIMRoomAllLeftResult>
Leave all rooms.
leaveGroup(String groupID) Future<ZIMGroupLeftResult>
Available since: 2.0.0 and above.
leaveRoom(String roomID) Future<ZIMRoomLeftResult>
Leave a room.
login(String userID, ZIMLoginConfig config) Future<void>
Login, you must log in before using all functions.
logout() → dynamic
Log out of ZIM service.
muteGroup(bool isMute, String groupID, ZIMGroupMuteConfig config) Future<ZIMGroupMutedResult>
Mute a group.
muteGroupMembers(bool isMute, List<String> userIDs, String groupID, ZIMGroupMemberMuteConfig config) Future<ZIMGroupMembersMutedResult>
Mute group members.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pinMessage(ZIMMessage message, bool isPinned) Future<void>
Pin message.
queryBlacklist(ZIMBlacklistQueryConfig config) Future<ZIMBlacklistQueriedResult>
todo
queryCallInvitationList(ZIMCallInvitationQueryConfig config) Future<ZIMCallInvitationListQueriedResult>
Supported versions: 2.9.0 and above. Detail description: Users can call the call invitation list through the query. Service scenario: Users can use the query call invitation list for interface display or other functions. When to call: Run create to create a ZIM instance, which can be invoked after login. Related callbacks: ZIMCallInvitationListQueriedCallback.
queryCombineMessageDetail(ZIMCombineMessage message) Future<ZIMCombineMessageDetailQueriedResult>
query combine message detail
queryConversation(String conversationID, ZIMConversationType conversationType) Future<ZIMConversationQueriedResult>
Query a conversation by conversation ID and conversation type.
queryConversationList(ZIMConversationQueryConfig config, [ZIMConversationFilterOption? option]) Future<ZIMConversationListQueriedResult>
Query the conversation list.
queryConversationPinnedList(ZIMConversationQueryConfig config) Future<ZIMConversationPinnedListQueriedResult>
Query the conversation pinned list.
queryConversationTotalUnreadMessageCount(ZIMConversationTotalUnreadMessageCountQueryConfig config) Future<ZIMConversationTotalUnreadMessageCountQueriedResult>
Query the total unread count of the conversation.
queryFriendApplicationList(ZIMFriendApplicationListQueryConfig config) Future<ZIMFriendApplicationListQueriedResult>
todo
queryFriendList(ZIMFriendListQueryConfig config) Future<ZIMFriendListQueriedResult>
todo
queryFriendsInfo(List<String> userIDs) Future<ZIMFriendsInfoQueriedResult>
todo
queryGroupAllAttributes(String groupID) Future<ZIMGroupAttributesQueriedResult>
todo
queryGroupApplicationList(ZIMGroupApplicationListQueryConfig config) Future<ZIMGroupApplicationListQueriedResult>
todo
queryGroupAttributes(List<String> keys, String groupID) Future<ZIMGroupAttributesQueriedResult>
todo
queryGroupInfo(String groupID) Future<ZIMGroupInfoQueriedResult>
todo
queryGroupList() Future<ZIMGroupListQueriedResult>
Available since: 2.0.0 and above.
queryGroupMemberCount(String groupID) Future<ZIMGroupMemberCountQueriedResult>
Available since: 2.2.0 or above.
queryGroupMemberInfo(String userID, String groupID) Future<ZIMGroupMemberInfoQueriedResult>
Available since: 2.0.0 and above.
queryGroupMemberList(String groupID, ZIMGroupMemberQueryConfig config) Future<ZIMGroupMemberListQueriedResult>
Available since: 2.0.0 and above.
queryGroupMemberMutedList(String groupID, ZIMGroupMemberMutedListQueryConfig config) Future<ZIMGroupMemberMutedListQueriedResult>
Query the list of group muted members.
queryGroupMessageReceiptReadMemberList(ZIMMessage message, String groupID, ZIMGroupMessageReceiptMemberQueryConfig config) Future<ZIMGroupMessageReceiptMemberListQueriedResult>
Available since: 2.5.0 and above.
queryGroupMessageReceiptUnreadMemberList(ZIMMessage message, String groupID, ZIMGroupMessageReceiptMemberQueryConfig config) Future<ZIMGroupMessageReceiptMemberListQueriedResult>
Available since: 2.5.0 and above.
queryHistoryMessage(String conversationID, ZIMConversationType conversationType, ZIMMessageQueryConfig config) Future<ZIMMessageQueriedResult>
Query historical messages.
queryLocalFileCache(ZIMFileCacheQueryConfig config) Future<ZIMFileCacheQueriedResult>
Query the local message cache of the current user.
queryMessageReactionUserList(ZIMMessage message, ZIMMessageReactionUserQueryConfig config) Future<ZIMMessageReactionUserListQueriedResult>
query message reaction userlist
queryMessageReceiptsInfo(List<ZIMMessage> messageList, String conversationID, ZIMConversationType conversationType) Future<ZIMMessageReceiptsInfoQueriedResult>
Query the receipt information of a batch of messages.
queryMessageRepliedList(ZIMMessage message, ZIMMessageRepliedListQueryConfig config) Future<ZIMMessageRepliedListQueriedResult>
Query message replied list.
queryMessages(List<int> messageSeqs, String conversationID, ZIMConversationType conversationType) Future<ZIMMessageQueriedResult>
Batch query messages by sequence.
queryPinnedMessageList(String conversationID, ZIMConversationType conversationType) Future<ZIMPinnedMessageListQueriedResult>
Query pinned message list.
queryRoomAllAttributes(String roomID) Future<ZIMRoomAttributesQueriedResult>
Query all properties of the room.
queryRoomMemberAttributesList(String roomID, ZIMRoomMemberAttributesQueryConfig config) Future<ZIMRoomMemberAttributesListQueriedResult>
paginate the room user properties that have room property members in the room.
queryRoomMemberList(String roomID, ZIMRoomMemberQueryConfig config) Future<ZIMRoomMemberQueriedResult>
Query the list of members in the room.
queryRoomMembers(List<String> userIDs, String roomID) Future<ZIMRoomMembersQueriedResult>
Query the information of the specified userID in the specified room.
queryRoomMembersAttributes(List<String> userIDs, String roomID) Future<ZIMRoomMembersAttributesQueriedResult>
Batch query the room user attributes of the members in the room.
queryRoomOnlineMemberCount(String roomID) Future<ZIMRoomOnlineMemberCountQueriedResult>
Query the number of online members in the room.
querySelfUserInfo() Future<ZIMSelfUserInfoQueriedResult>
Query user information and user rules.
querySubscribedUserStatusList(ZIMSubscribedUserStatusQueryConfig config) Future<ZIMSubscribedUserStatusListQueriedResult>
Query subscribed user status list.
queryUsersInfo(List<String> userIDs, ZIMUserInfoQueryConfig config) Future<ZIMUsersInfoQueriedResult>
Query user information.
queryUsersStatus(List<String> userIDs) Future<ZIMUsersStatusQueriedResult>
Query user status.
rejectFriendApplication(String userID, ZIMFriendApplicationRejectConfig config) Future<ZIMFriendApplicationRejectedResult>
todo
rejectGroupInviteApplication(String inviterUserID, String groupID, ZIMGroupInviteApplicationRejectConfig config) Future<ZIMGroupInviteApplicationRejectedResult>
todo
rejectGroupJoinApplication(String userID, String groupID, ZIMGroupJoinApplicationRejectConfig config) Future<ZIMGroupJoinApplicationRejectedResult>
todo
removeUsersFromBlacklist(List<String> userIDs) Future<ZIMBlacklistUsersRemovedResult>
todo
renewToken(String token) Future<ZIMTokenRenewedResult>
Update the authentication token.
replyMessage(ZIMMessage message, ZIMMessage toOriginalMessage, ZIMMessageSendConfig config, ZIMMessageSendNotification? notification) Future<ZIMMessageSentResult>
Reply message.
revokeMessage(ZIMMessage message, ZIMMessageRevokeConfig config) Future<ZIMMessageRevokedResult>
revoke message.
searchGlobalLocalMessages(ZIMMessageSearchConfig config) Future<ZIMMessagesGlobalSearchedResult>
Search global local message list.
searchLocalConversations(ZIMConversationSearchConfig config) Future<ZIMConversationsSearchedResult>
Search local conversations on local messages.
searchLocalFriends(ZIMFriendSearchConfig config) Future<ZIMFriendsSearchedResult>
todo
searchLocalGroupMembers(String groupID, ZIMGroupMemberSearchConfig config) Future<ZIMGroupMembersSearchedResult>
Search local group members.
searchLocalGroups(ZIMGroupSearchConfig config) Future<ZIMGroupsSearchedResult>
Search local group members.
searchLocalMessages(String conversationID, ZIMConversationType conversationType, ZIMMessageSearchConfig config) Future<ZIMMessagesSearchedResult>
Search local message list.
sendConversationMessageReceiptRead(String conversationID, ZIMConversationType conversationType) Future<ZIMConversationMessageReceiptReadSentResult>
Sets all received receipts for the conversation as read.
sendFriendApplication(String userID, ZIMFriendApplicationSendConfig config) Future<ZIMFriendApplicationSentResult>
todo
sendGroupInviteApplications(List<String> userIDs, String groupID, ZIMGroupInviteApplicationSendConfig config) Future<ZIMGroupInviteApplicationsSentResult>
todo
sendGroupJoinApplication(String groupID, ZIMGroupJoinApplicationSendConfig config) Future<ZIMGroupJoinApplicationSentResult>
todo
sendGroupMessage(ZIMMessage message, String toGroupID, ZIMMessageSendConfig config) Future<ZIMMessageSentResult>
Send group messages.
sendMediaMessage(ZIMMediaMessage message, String toConversationID, ZIMConversationType conversationType, ZIMMessageSendConfig config, ZIMMediaMessageSendNotification? notification) Future<ZIMMessageSentResult>
Send media messages.
sendMessage(ZIMMessage message, String toConversationID, ZIMConversationType conversationType, ZIMMessageSendConfig config, [ZIMMessageSendNotification? notification]) Future<ZIMMessageSentResult>
send message.
sendMessageReceiptsRead(List<ZIMMessage> messageList, String conversationID, ZIMConversationType conversationType) Future<ZIMMessageReceiptsReadSentResult>
Set the receipt of a batch of messages to become read.
sendPeerMessage(ZIMMessage message, String toUserID, ZIMMessageSendConfig config) Future<ZIMMessageSentResult>
Send peer-to-peer messages.
sendRoomMessage(ZIMMessage message, String toRoomID, ZIMMessageSendConfig config) Future<ZIMMessageSentResult>
Send room messages.
setConversationDraft(String draft, String conversationID, ZIMConversationType conversationType) Future<ZIMConversationDraftSetResult>
Set the conversation notification state.
setConversationMark(int mark, bool enable, List<ZIMConversationBaseInfo> conversationInfos) Future<ZIMConversationMarkSetResult>
Set the conversation marked status.
setConversationNotificationStatus(ZIMConversationNotificationStatus status, String conversationID, ZIMConversationType conversationType) Future<ZIMConversationNotificationStatusSetResult>
Set the conversation notification state.
setGroupAttributes(Map<String, String> groupAttributes, String groupID) Future<ZIMGroupAttributesOperatedResult>
todo
setGroupMemberNickname(String nickname, String forUserID, String groupID) Future<ZIMGroupMemberNicknameUpdatedResult>
todo
setGroupMemberRole(int role, String forUserID, String groupID) Future<ZIMGroupMemberRoleUpdatedResult>
todo
setRoomAttributes(Map<String, String> roomAttributes, String roomID, ZIMRoomAttributesSetConfig config) Future<ZIMRoomAttributesOperatedCallResult>
Set room attributes (use this for all additions and changes).
setRoomMembersAttributes(Map<String, String> attributes, List<String> userIDs, String roomID, ZIMRoomMemberAttributesSetConfig config) Future<ZIMRoomMembersAttributesOperatedResult>
Set room member attributes (use this for all additions and changes).
subscribeUsersStatus(List<String> userIDs, ZIMUserStatusSubscribeConfig config) Future<ZIMUsersStatusSubscribedResult>
Subscribe to user status.
switchRoom(String fromRoomID, ZIMRoomInfo toRoomInfo, bool isCreateWhenRoomNotExisted, ZIMRoomAdvancedConfig config) Future<ZIMRoomSwitchedResult>
Switch room.
toString() String
A string representation of this object.
inherited
transferGroupOwner(String toUserID, String groupID) Future<ZIMGroupOwnerTransferredResult>
Available since: 2.0.0 and above. Description: After a group is created, the group owner can use this method to assign the group owner to a specified user. Use cases: In a group chat scenario, you can transfer the group master through this interface. When to call /Trigger: The ZIM instance can be invoked after being created by create and logged in. Restrictions: You cannot transfer a group owner if you are not a group owner. Related APIs: Through the callback ZIMGroupOwnerTransferredCallback can get the result of the transfer of the group manager.
unsubscribeUsersStatus(List<String> userIDs) Future<ZIMUsersStatusUnsubscribedResult>
Unsubscribe from user status.
updateConversationPinnedState(bool isPinned, String conversationID, ZIMConversationType conversationType) Future<ZIMConversationPinnedStateUpdatedResult>
Modify the conversation pinned state.
updateFriendAlias(String friendAlias, String userID) Future<ZIMFriendAliasUpdatedResult>
todo
updateFriendAttributes(Map<String, String> friendAttributes, String userID) Future<ZIMFriendAttributesUpdatedResult>
todo
updateGroupAlias(String groupAlias, String groupID) Future<ZIMGroupAliasUpdatedResult>
todo
updateGroupAvatarUrl(String groupAvatarUrl, String groupID) Future<ZIMGroupAvatarUrlUpdatedResult>
todo
updateGroupBeInviteMode(ZIMGroupBeInviteMode mode, String groupID) Future<ZIMGroupBeInviteModeUpdatedResult>
Available since: 2.15.0 and above. Description: When a group is created, the group owner and administrators can use this method to update the group verification mode. Use cases: You need to update the group bulletin in the group. When to call /Trigger: The ZIM instance can be invoked after being created by create and logged in.
updateGroupInviteMode(ZIMGroupInviteMode mode, String groupID) Future<ZIMGroupInviteModeUpdatedResult>
Available since: 2.15.0 and above. Description: When a group is created, the group owner and administrators can use this method to update the group verification mode. When to call /Trigger: The ZIM instance can be invoked after being created by create and logged in.
updateGroupJoinMode(ZIMGroupJoinMode mode, String groupID) Future<ZIMGroupJoinModeUpdatedResult>
Available since: 2.15.0 and above. Description: When a group is created, the group owner and administrators can use this method to update the group verification mode. Use cases: You need to update the group bulletin in the group. When to call /Trigger: The ZIM instance can be invoked after being created by create and logged in.
updateGroupName(String groupName, String groupID) Future<ZIMGroupNameUpdatedResult>
Available since: 2.0.0 and above. Description: After a group is created, users can call this method to change the group name. Use cases: After creating a group, you need to change the group name. When to call /Trigger: The ZIM instance can be invoked after being created by create and logged in. Restrictions: Group members and group owners can change the group name. The maximum length of the name is 100 bytes. Related APIs: Through the callback ZIMGroupNameUpdatedCallback can get the result of the change of name, through onGroupNoticeUpdated can get update group name information.
updateGroupNotice(String groupNotice, String groupID) Future<ZIMGroupNoticeUpdatedResult>
todo
updateMessageLocalExtendedData(String localExtendedData, ZIMMessage message) Future<ZIMMessageLocalExtendedDataUpdatedResult>
Update the local expandable field of the message.
updateUserAvatarUrl(String userAvatarUrl) Future<ZIMUserAvatarUrlUpdatedResult>
Update user's avatar URL.
updateUserCustomStatus(String customStatus) Future<ZIMUserCustomStatusUpdatedResult>
Update user's custom status.
updateUserExtendedData(String extendedData) Future<ZIMUserExtendedDataUpdatedResult>
Update user's user extended data.
updateUserName(String userName) Future<ZIMUserNameUpdatedResult>
Update user's user name.
updateUserOfflinePushRule(ZIMUserOfflinePushRule offlinePushRule) Future<ZIMUserOfflinePushRuleUpdatedResult>
Update user's custom rule of offline push.
uploadLog() Future<void>
Upload log and call after setting up log path.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create(ZIMAppConfig config) ZIM?
Initialize ZIM SDK
getInstance() ZIM?
Get the ZIM singleton object.
getVersion() Future<String>
Gets the SDK's version number.
setAdvancedConfig(String key, String value) → void
Set ZIM advanced configuration.
setCacheConfig(ZIMCacheConfig config) → void
Set cache related configuration.
setGeofencingConfig(List<int> areaList, ZIMGeofencingType type) Future<bool>
Set geofence-related configurations.
setLogConfig(ZIMLogConfig config) → void
Set log related configuration.