beginRoomAttributesBatchOperation abstract method

void beginRoomAttributesBatchOperation(
  1. String roomID,
  2. ZIMRoomAttributesBatchOperationConfig config
)

Open combination room attribute operation.

Available since: 1.3.0. Description: Used to turn on the combination of room attributes.

  • roomID The number of the room where the combined operation needs to be turned on.
  • config The configuration of the combined operation.

Implementation

void beginRoomAttributesBatchOperation(
    String roomID, ZIMRoomAttributesBatchOperationConfig config);