clearConversationUnreadMessageCount abstract method

Future<ZIMConversationUnreadMessageCountClearedResult> clearConversationUnreadMessageCount(
  1. String conversationID,
  2. ZIMConversationType conversationType
)

clear session unreads.

Available since: 2.0.0 and above. Description: Used to clear unread for the current user target session. Use cases: This interface is called when a chat page is entered from a session and the original message readings of the session need to be cleared. When to call: Called when a target needs to be cleared without readings. Restrictions: Valid after login, invalid after logout. Scope of impact: Calling this method will trigger a total readings not updated callback onConversationTotalUnreadMessageCountUpdated, would trigger a session to update callbacks onConversationChanged. Related callbacks: ZIMConversationUnreadMessageCountClearedResult. Related APIs: onConversationTotalUnreadMessageCountUpdatedonConversationChanged.

  • conversationID conversationID.
  • conversationType conversation type.

Implementation

Future<ZIMConversationUnreadMessageCountClearedResult>
clearConversationUnreadMessageCount(
  String conversationID,
  ZIMConversationType conversationType,
);