create static method
Create a ZIM instance.
Available since: 2.3.0 and above.
Description: Create a ZIM instance for subsequent calls to other member functions.
When to call: Before calling other member functions, you must call this API to create a ZIM example.
Restrictions: Currently only one instance is supported, repeated calls will return null.
Caution:
- Currently, the create function can only create one instance at most. If it is called multiple times, only the first one will return a valid instance, and the rest will be
null. The developer should save the ZIM instance by himself, and ensure that the life cycle of the instance is available in the process of using the ZIM business function; or after calling create, he can use getInstance to obtain its singleton object and call other member functions. - If you use this function to create an instance, you must pass in both AppID and AppSign (exclude Web platform). Scope of impact: Failure to call this function will prevent other member functions from being called. Platform differences: When calling this function on the Android platform, in addition to the appID, the Application class object must also be passed in.
appConfigZIMAppConfig
Implementation
static ZIM? create(ZIMAppConfig appConfig) {
return ZIMManager.create(appConfig);
}