createRoom abstract method

Future<ZIMRoomCreatedResult> createRoom(
  1. ZIMRoomInfo roomInfo, [
  2. ZIMRoomAdvancedConfig? config
])

Create a room with advanced settings

Available since: 1.3.0. Description: Users can create and join rooms through this api, other users can join this room through joinRoom function.

  • roomInfo The configuration information of the room to be created.
  • config The advanced properties of the room to be created.

Implementation

Future<ZIMRoomCreatedResult> createRoom(ZIMRoomInfo roomInfo,
    [ZIMRoomAdvancedConfig? config]);