deleteAllMessage abstract method

Future<ZIMMessageDeletedResult> deleteAllMessage(
  1. String conversationID,
  2. ZIMConversationType conversationType,
  3. ZIMMessageDeleteConfig config
)

Delete all message.

Supported versions: 2.0.0 and above. Detail description: When you need to delete all messages under the target session, call this method. Business scenario: If you want to implement a group setting page to clear the chat information under the current session, you can call this interface. Call timing/Notify timing: The target session exists and the user is a member of this session. Restrictions: Effective after login, invalid after logout. Note: The impact of deleting messages is limited to this account, and messages from other accounts will not be deleted. Impacts on other APIs: The conversationChanged callback is triggered, and if there are unread messages, the conversationTotalUnreadMessageCountUpdated callback is triggered. Related callbacks: ZIMMessageDeletedCallback.

  • conversationID The session ID of the message to be deleted.
  • conversationType conversation type.
  • config delete message configuration.

Implementation

Future<ZIMMessageDeletedResult> deleteAllMessage(
  String conversationID,
  ZIMConversationType conversationType,
  ZIMMessageDeleteConfig config,
);