deleteGroupAttributes abstract method

Future<ZIMGroupAttributesOperatedResult> deleteGroupAttributes(
  1. List<String> keys,
  2. String groupID
)

todo

Available since: 2.0.0 and above. Description: When a group already exists, you can use this method to delete group attributes. Both the master and members of the interface group can be invoked. Use cases: Deleted the extended field of the group description. When to call /Trigger: The ZIM instance can be invoked after being created by create and logged in. Restrictions: Only group members can delete group attributes. Related callbacks: Through the callback ZIMGroupAttributesOperatedCallback can delete the result of the group of attributes. Related APIs: You can use setGroupAttributes to setGroupAttributes, queryGroupAttributes to queryGroupAttributes, and queryAllGroupAttributes to queryAllGroupAttributes.

  • keys
  • groupID

Implementation

Future<ZIMGroupAttributesOperatedResult> deleteGroupAttributes(
    List<String> keys, String groupID);