deleteRoomAttributes abstract method

Delete room attributes.

Available since: 1.3.0. Description: Used to delete room attributes.

  • keys The key of the room attribute to be deleted.
  • roomID To modify the room number of the room attribute
  • config Behavior configuration of the operation.

Implementation

Future<ZIMRoomAttributesOperatedCallResult> deleteRoomAttributes(
    List<String> keys, String roomID, ZIMRoomAttributesDeleteConfig config);