destroy abstract method
dynamic
destroy()
Destroy the ZIM instance.
Supported version: 1.1.0 and above. Detailed description: Release the resources used by the ZIM instance. This function must be called to release the occupied memory resources when ZIM is no longer needed, otherwise a memory leak may occur. Call timing: call when ZIM is no longer needed, usually before emptying the ZIM object. Note: After calling this function, ZIM internal functions can no longer be used, and all callback notifications will no longer be triggered. If you need to continue using the ZIM function, please call create again to create a new instance.
Implementation
destroy();