downloadMediaFile abstract method

Download media message content.

Supported versions: 2.19.0 and above. Detailed description: This method can be used to download the content of media messages, including the original image, large image, thumbnail image, file message, audio message, video message and the first frame of the image message. Service scenario: After the user receives a message, if the message is a media message, he can call this API to download its content.You cannot Download Network urls before 2.9.0. Invoke timing/notification timing: can be invoked after logging in and receiving a media message. Note: If sendMediaMessage sends a network URL, SDK earlier than 2.9.0 cannot be downloaded through this interface. Restrictions: If you download an external URL, you can only download a maximum of 200MB of resources. For configuration, please contact ZEGO technical support. Related callbacks: ZIMMediaDownloadedCallback, ZIMMediaDownloadingProgress.

  • message The media message to download.
  • fileType Media file type.
  • config Download media file configuration.
  • progress Progress callback for downloading media files.

Implementation

Future<ZIMMediaDownloadedResult> downloadMediaFile(
  ZIMMessage message,
  ZIMMediaFileType fileType,
  ZIMMediaDownloadConfig config,
  ZIMMediaDownloadingProgress progress,
);