exportLocalMessages abstract method

Future<void> exportLocalMessages(
  1. String folderPath,
  2. ZIMMessageExportConfig config,
  3. ZIMMessageExportingProgress progress
)

Example Export the local message of the current user.

Available sinces: 2.15.0 and above. Detail description: This method is used to export the local message of the current user. Use cases: It can be used to migrate local chat records by calling this interface to export local message files. Restrictions: You can only use it after logging in. Caution: The name of the message file exported by this interface is zim_backup_msg_text. If the passed in path is the same when calling this interface multiple times, the ZIM SDK will rename the old zim_backup_msg_text file by itself to ensure that the latest exported file name is zim_backup_msg_text. Related callbacks: ZIMMessageExportedCallback.

  • folderPath The path of the export file to be output.
  • config todo
  • progress todo

Implementation

Future<void> exportLocalMessages(
  String folderPath,
  ZIMMessageExportConfig config,
  ZIMMessageExportingProgress progress,
);