getInstance static method

ZIM? getInstance()

Get the ZIM singleton object.

Supported versions: 2.3.0 and above. Detailed description: Get the ZIM singleton object for subsequent calls to other member functions. When to call: You must call create to create an instance before calling this function to obtain a singleton object, otherwise it will return null. Related interface: create.

Implementation

static ZIM? getInstance() {
  return ZIMManager.getInstance();
}