importLocalMessages abstract method

Future<void> importLocalMessages(
  1. String folderPath,
  2. ZIMMessageImportConfig config,
  3. ZIMMessageImportingProgress progress
)

Import local messages of the current user.

Available sinces: 2.15.0 and above. Detail description: This method is used to import the local message of the current user. Use cases: It can be used to migrate local chat records by calling this interface to import local message files. Restrictions: You can only use it after logging in. Caution: The ZIM SDK reads a file named zim_backup_msg_text in the directory by default. If there are multiple backups in this path, please confirm whether the name of the file to be imported is zim_backup_msg_text. Related callbacks: ZIMMessageImportedCallback.

  • folderPath The path of the import file to be output.
  • config todo
  • progress todo

Implementation

Future<void> importLocalMessages(
  String folderPath,
  ZIMMessageImportConfig config,
  ZIMMessageImportingProgress progress,
);