joinRoom abstract method

Future<ZIMRoomJoinedResult> joinRoom(
  1. String roomID
)

Join a room.

Available since: 1.1.0 or above. Description: If the room does not exist, the join fails and you need to call createRoom to create the room first. Use cases: In a multi-person chat scenario, users can call this interface to enter the room when they need to join the room. When to call: It can be called after creating a ZIM instance through create. Caution: When everyone leaves the room, the room will be automatically destroyed. Related callbacks: The result of joining the room can be obtained through the ZIMRoomJoinedCallback callback. Related APIs: You can create a room with createRoom and leave the room with leaveRoom.

  • roomID ID of the room to join.

Implementation

Future<ZIMRoomJoinedResult> joinRoom(String roomID);