kickGroupMembers abstract method

Future<ZIMGroupMemberKickedResult> kickGroupMembers(
  1. List<String> userIDs,
  2. String groupID
)

Available since: 2.0.0 and above. Description: After a user joins a group, you can use this method to remove the user from the group. Use cases: You can use this method to remove one or more users from the group. When to call /Trigger: The ZIM instance can be invoked after being created by create and logged in. Restrictions: You can't kick someone unless you're the leader of the group. Caution: This interface does not require the peer's consent or the peer's online status. It cannot accept group-related callbacks after being kicked out. History messages and sessions remain after being kicked out and can still enter the group. Related callbacks: Through the callback ZIMGroupMemberKickedCallback can get the user kicked out the results of the group. Related APIs: You can invite a target user into a group through inviteUsersIntoGroup.

  • userIDs
  • groupID

Implementation

Future<ZIMGroupMemberKickedResult> kickGroupMembers(
    List<String> userIDs, String groupID);