muteGroupMembers abstract method

Future<ZIMGroupMembersMutedResult> muteGroupMembers(
  1. bool isMute,
  2. List<String> userIDs,
  3. String groupID,
  4. ZIMGroupMemberMuteConfig config,
)

Mute group members.

Available since: 2.14.0 and above. Description: Once a group is created, the group administrator can call this interface to implement group members muting and unmuting. Use cases: After creating a group, users need to change the mute status of the group members. When to call /Trigger: This can be called after a ZIM instance is created using create and logged into the group. Restrictions: This can be called by the group owner and group administrators. Related callbacks: The result of changing the group members mute status can be obtained through the ZIMGroupMembersMutedCallback callback. The updated group members mute status information can be obtained through onGroupMemberInfoUpdated.

  • isMute isMute
  • userIDs userIDs
  • groupID groupID
  • config config

Implementation

Future<ZIMGroupMembersMutedResult> muteGroupMembers(
  bool isMute,
  List<String> userIDs,
  String groupID,
  ZIMGroupMemberMuteConfig config,
);