queryConversation abstract method

Future<ZIMConversationQueriedResult> queryConversation(
  1. String conversationID,
  2. ZIMConversationType conversationType
)

Query a conversation by conversation ID and conversation type.

Available since: 2.8.0 and above. Description: This method displays the session list of the logged in user. Use cases: When you need to know the relevant information of the specified conversation, you can call this interface to obtain the data source. When to call /Trigger: Can be invoked after login. Restrictions:There is no limit to the frequency of use, available after login, unavailable after logout. Related callbacks: ZIMConversationQueriedCallback.

  • conversationID Conversation ID.
  • conversationType Conversation type.

Implementation

Future<ZIMConversationQueriedResult> queryConversation(
  String conversationID,
  ZIMConversationType conversationType,
);