queryConversationList abstract method
Future<ZIMConversationListQueriedResult>
queryConversationList(
- ZIMConversationQueryConfig config, [
- ZIMConversationFilterOption? option
Query the conversation list.
Use cases: This interface can be invoked to get the data source when you need to display an existing message session after logging in. When to call: Can be invoked after login. Caution: NextConversation is the riveting point of the query message, which can be null for the first query. In subsequent query, the earliest conversation can be used as nextConversation to query earlier sessions. In paging query, Count in ZIMConversationQueryConfig fill each pull the number of sessions. Related callbacks: ZIMConversationListQueriedCallback. Related APIs: deleteConversation Deletes the session. clearConversationUnreadMessageCount clear session readings.
configConfiguration for session queries.optionFilter options for session queries.
Implementation
Future<ZIMConversationListQueriedResult> queryConversationList(
ZIMConversationQueryConfig config, [
ZIMConversationFilterOption? option,
]);