queryGroupAttributes abstract method

Future<ZIMGroupAttributesQueriedResult> queryGroupAttributes(
  1. List<String> keys,
  2. String groupID
)

todo

Available since: 2.0.0 and above. Description: After a group is created, you can use this method to query the specified group properties. Use cases: You need to query the scenarios to display the specified group attributes. When to call /Trigger: After creating a ZIM instance with create and logging in with login. Restrictions: Available after login, unavailable after logout. Related callbacks: Through the callback ZIMGroupAttributesQuriedCallback can get query attributes of the specified group of results. Related APIs: queryAllGroupAttributes Queries all group attributes.

  • keys
  • groupID

Implementation

Future<ZIMGroupAttributesQueriedResult> queryGroupAttributes(
    List<String> keys, String groupID);