queryGroupList abstract method

Future<ZIMGroupListQueriedResult> queryGroupList({
  1. int? count,
  2. ZIMGroupListQueryConfig? config,
})

Query the group list.

Available since: 2.27.0 and above. Description: Query the list of all groups. Use cases: You need to get a list of groups to display. When to call: The ZIM instance can be invoked after being created by create and logged in. Restrictions: Available after login, unavailable after logout. Related callbacks: Through the callback ZIMGroupListQueriedResult can get a check list of all current group results.

  • count The number of groups to query.
  • config Group list query configuration.

Implementation

Future<ZIMGroupListQueriedResult> queryGroupList({
  int? count,
  ZIMGroupListQueryConfig? config,
});