queryGroupMemberInfo abstract method

Future<ZIMGroupMemberInfoQueriedResult> queryGroupMemberInfo(
  1. String userID,
  2. String groupID
)

Available since: 2.0.0 and above.

Description: After a group is created, you can use this method to query information about a specified group member.

Use cases: You need to obtain the specified group member information for display or interaction.

When to call /Trigger: The ZIM instance can be invoked after being created by create and logged in.

Restrictions: Available after login, unavailable after logout.

Related callbacks: Through the callback ZIMGroupMemberInfoQueriedCallback can get the query specifies the result of group membership information.

  • userID User ID of the queried member information.

  • groupID The ID of the group whose member information will be queried.

  • callback Callback for the result of querying group member information.

  • userID userID

  • groupID groupID

Implementation

Future<ZIMGroupMemberInfoQueriedResult> queryGroupMemberInfo(
  String userID,
  String groupID,
);