queryGroupMemberList abstract method
Future<ZIMGroupMemberListQueriedResult>
queryGroupMemberList(
- String groupID,
- ZIMGroupMemberQueryConfig config
Query the list of group members.
Available since: 2.0.0 and above. Description: After a group is created, you can use this method to query the group member list. Use cases: You need to obtain the specified group member list for display or interaction. When to call: The ZIM instance can be invoked after being created by create and logged in. Restrictions: Available after login, unavailable after logout. Related callbacks: Through the callback ZIMGroupMemberListQueriedResult can query the result of the group member list.
groupIDThe group ID of the group member list to be queried.configGroup member query configuration.
Implementation
Future<ZIMGroupMemberListQueriedResult> queryGroupMemberList(
String groupID,
ZIMGroupMemberQueryConfig config,
);