queryGroupMemberMutedList abstract method

Query the list of group muted members.

Available since: 2.14.0 and above. Description: After a group is created, you can use this method to query the group muted member list. Use cases: You need to obtain the specified group muted member list for display or interaction. When to call: The ZIM instance can be invoked after being created by create and logged in. Restrictions: Available after login, unavailable after logout. Related callbacks: Through the callback ZIMGroupMembersMutedResult can query the result of the group muted member list.

  • groupID The target group ID.
  • config Group muted member list query configuration.

Implementation

Future<ZIMGroupMemberMutedListQueriedResult> queryGroupMemberMutedList(
  String groupID,
  ZIMGroupMemberMutedListQueryConfig config,
);