queryLocalFileCache abstract method

Query the local message cache of the current user.

Supported versions: 2.15.0 and above. Detail description: Query the local message cache of the current user. Business scenario: This interface is invoked when the local message cache needs to be queried. Restrictions: This takes effect after the login and becomes invalid after the logout. Related callbacks: ZIMFileCacheQueriedCallback.

  • config Query the cache configuration.

Implementation

Future<ZIMFileCacheQueriedResult> queryLocalFileCache(
    ZIMFileCacheQueryConfig config);