queryMessageReceiptsInfo abstract method

Future<ZIMMessageReceiptsInfoQueriedResult> queryMessageReceiptsInfo(
  1. List<ZIMMessage> messageList,
  2. String conversationID,
  3. ZIMConversationType conversationType
)

Query the receipt information of a batch of messages.

Available since: 2.5.0 and above. Description: This method can query the receipt information of a batch of messages, including the status, the number of unread users and the number of read users. Use cases: If you need to query the receipt status of the message, the number of unread users and the number of read users, you can call this interface. When to call: Callable after login. If you need to query the detailed member list, you can query through the interface queryGroupMessageReceiptReadMemberList or queryGroupMessageReceiptUnreadMemberList. Restrictions: Only messages whose statuses are not NONE and UNKNOWN are supported. Related callbacks: ZIMMessageReceiptsInfoQueriedCallback. Related APIs: queryGroupMessageReceiptReadMemberList , queryGroupMessageReceiptUnreadMemberList.

  • messageList list of messages to query.
  • conversationID Conversation ID.
  • conversationType Conversation type.

Implementation

Future<ZIMMessageReceiptsInfoQueriedResult> queryMessageReceiptsInfo(
  List<ZIMMessage> messageList,
  String conversationID,
  ZIMConversationType conversationType,
);