queryRoomMemberList abstract method
- String roomID,
- ZIMRoomMemberQueryConfig config
Query the list of members in the room.
Available since: 1.1.0 or above.
Description: After joining a room, you can use this function to get the list of members in the room.
Use cases: When a developer needs to obtain a list of room members for other business operations, this interface can be called to obtain a list of members.
When to call: After creating a ZIM instance through create, and the user is in the room that needs to be queried, you can call this interface.
Caution: If the user is not currently in this room, the query fails. When there are more than 500 room members, the result of querying the list of room members can only contain the information of a maximum of 500 members.
Related callbacks: Through the ZIMRoomMemberQueriedCallback callback, you can get the result of querying the room member list.
Related APIs: You can check the online number of people in the room through queryRoomOnlineMemberCount.
roomIDID of the room to query.configConfiguration of query room member operation.
Implementation
Future<ZIMRoomMemberQueriedResult> queryRoomMemberList(
String roomID, ZIMRoomMemberQueryConfig config);