queryRoomMembersAttributes abstract method

Future<ZIMRoomMembersAttributesQueriedResult> queryRoomMembersAttributes(
  1. List<String> userIDs,
  2. String roomID
)

Batch query the room user attributes of the members in the room.

Available since:2.4.0 or later. Description:Call this API to batch query the room user attributes of the members in the room. Use cases:Use this interface when you need to specify that you want to query some room users. Restrictions:The maximum call frequency is 5 times within 30 seconds by default, and the maximum query time is 100 people. Related callbacks:ZIMRoomMembersAttributesQueriedCallback. Related APIs: setRoomMembersAttributesqueryRoomMemberAttributesList. Runtime lifecycle: It is available after logging in and joining the corresponding room, but unavailable after leaving the corresponding room.

  • userIDs A list of userIDs to query.
  • roomID Room ID.

Implementation

Future<ZIMRoomMembersAttributesQueriedResult> queryRoomMembersAttributes(
  List<String> userIDs,
  String roomID,
);