queryRoomOnlineMemberCount abstract method

Future<ZIMRoomOnlineMemberCountQueriedResult> queryRoomOnlineMemberCount(
  1. String roomID
)

Query the number of online members in the room.

Available since: 1.1.0 or above. Description: After joining a room, you can use this function to get the number of online members in the room. Use cases: When a developer needs to obtain the number of room members who are online, this interface can be called. Calling time: After creating a ZIM instance through create, and the user is in the room that needs to be queried, this interface can be called. Caution: If the user is not currently in this room, the query will fail. Related callbacks: The result of querying the online number of room members can be obtained through the ZIMRoomOnlineMemberCountQueriedCallback callback. Related APIs: the room member can be inquired through queryRoomMember.

  • roomID ID of the room to query.

Implementation

Future<ZIMRoomOnlineMemberCountQueriedResult> queryRoomOnlineMemberCount(
    String roomID);