sendConversationMessageReceiptRead abstract method
- String conversationID,
- ZIMConversationType conversationType
Sets all received receipts for the conversation as read.
Available since: 2.5.0 and above.
Description: Set all received receipts of the conversation to be read.
Use cases: Set all received receipt messages in the entire conversation to be read, and the sender of the message receipt in the conversation will receive the onConversationMessageReceiptChanged callback from ZIMEventHandler.
When to call: It can be called after login. It is recommended to call before entering the message list page. In the message list page, it is recommended to call sendMessageReceiptsRead to batch set the messages that need to be read.
Caution: Only single chat conversation are allowed.
Related callbacks: ZIMConversationMessageReceiptReadSentResult.
Related APIs: sendMessageReceiptsRead, sendMessage.
conversationIDConversation ID.conversationTypeConversation type, such as peer, group, etc.
Implementation
Future<ZIMConversationMessageReceiptReadSentResult>
sendConversationMessageReceiptRead(
String conversationID,
ZIMConversationType conversationType,
);