sendMessageReceiptsRead abstract method
Future<ZIMMessageReceiptsReadSentResult>
sendMessageReceiptsRead(
- List<
ZIMMessage> messageList, - String conversationID,
- ZIMConversationType conversationType
Set the receipt of a batch of messages to become read.
Available since: 2.5.0 and above.
Description: This method can set the receipt of a batch of messages to become read.
Use cases: Developers can use this method to set a batch of messages with receipts that have been read. If the sender is online, it will receive the onMessageReceiptChanged callback.
When to call: Callable after login. It is recommended to set the settings for the messages that need to be read on the message list page. It is not recommended to mix with sendConversationMessageReceiptRead.
Restrictions: Only support the settings for received messages with receipt status as PROCESSING.
Related callbacks: ZIMMessageReceiptsReadSentCallback.
Related APIs: sendMessage.
messageListThe list of messages to be read with no more than 10 messages.conversationIDConversation ID.conversationTypeConversation type.
Implementation
Future<ZIMMessageReceiptsReadSentResult> sendMessageReceiptsRead(
List<ZIMMessage> messageList,
String conversationID,
ZIMConversationType conversationType,
);