sendRoomMessage abstract method

  1. @Deprecated('This API has been deprecated since 2.4.0, use [sendMessage] instead.')
Future<ZIMMessageSentResult> sendRoomMessage(
  1. ZIMMessage message,
  2. String toRoomID,
  3. ZIMMessageSendConfig config
)

Send room messages.

Available since: 1.1.0 or above Description: When this function is called, the message will be sent in the room. At the same time, the ZIMMessageSentCallback callback will be received, which can be used to determine whether the message was sent successfully. Use Cases: This feature is required for scenarios where multiple people in the room are chatting.

@deprecated This API has been deprecated since 2.4.0, use sendMessage instead.

  • message The message to be sent.
  • toRoomID The ID of the room which will receive the message.
  • config Related configuration for sending room messages.

Implementation

@Deprecated(
    'This API has been deprecated since 2.4.0, use [sendMessage] instead.')
Future<ZIMMessageSentResult> sendRoomMessage(
    ZIMMessage message, String toRoomID, ZIMMessageSendConfig config);