setConversationDraft abstract method

Future<ZIMConversationDraftSetResult> setConversationDraft(
  1. String draft,
  2. String conversationID,
  3. ZIMConversationType conversationType
)

Set the conversation notification state.

Available since: 2.14.0 and above. Description: When you need to set a draft for a session, call this interface, and members of the session can call this interface. Use cases: This interface can be invoked when you need to temporarily save the text message that the user is editing but has not yet sent. When to call /Trigger: Call when you need to set session draft, call after creating ZIM instance, take effect after login, invalid after logout. Impacts on other APIs: A successful call triggers the onConversationchanged callback. Related callbacks: ZIMConversationDraftSetCallback.

  • draft Drafts that need to be set.
  • conversationID Conversation ID.
  • conversationType todo

Implementation

Future<ZIMConversationDraftSetResult> setConversationDraft(
  String draft,
  String conversationID,
  ZIMConversationType conversationType,
);