setConversationNotificationStatus abstract method

Future<ZIMConversationNotificationStatusSetResult> setConversationNotificationStatus(
  1. ZIMConversationNotificationStatus status,
  2. String conversationID,
  3. ZIMConversationType conversationType
)

Set the conversation notification state.

Available since: 2.0.0 and above. Description: This method enables DND by selecting whether the unread of the target session is updated when a message is received. Use cases: If the user selects MESSAGE DO not Disturb (DND), the user can call the corresponding method. Default value: Message DND is disabled by default. When to call /Trigger: If the target session exists after login, invoke this interface if you want to enable the DND status of the target session. Restrictions: Valid after login, invalid after logout. Impacts on other APIs: After the DND state is enabled, receiving messages is not triggered conversationTotalUnreadMessageCountUpdated。 Related callbacks: ZIMConversationNotificationStatusSetCallback。 Related APIs: conversationTotalUnreadMessageCountUpdated

  • status the session notification state.
  • conversationID Conversation ID. Currently, only "group" conversations and "peer"(only for 2.14.0 or above version) conversations can be set by notification state.
  • conversationType todo

Implementation

Future<ZIMConversationNotificationStatusSetResult>
    setConversationNotificationStatus(
        ZIMConversationNotificationStatus status,
        String conversationID,
        ZIMConversationType conversationType);