setGroupAttributes abstract method

Future<ZIMGroupAttributesOperatedResult> setGroupAttributes(
  1. Map<String, String> groupAttributes,
  2. String groupID
)

todo

Available since: 2.0.0 and above. Description: If a group already exists, all users of the group can use this method to set group properties. Use cases: Added extended field information about group description, such as group family, label, and industry category. When to call /Trigger: The ZIM instance can be invoked after being created by create and logged in. Restrictions: Only group members can set group properties. Related callbacks: Through the callback ZIMGroupAttributesOperatedCallback can get the result of the set of properties. Related APIs: deleteGroupAttributes can be used to deleteGroupAttributes, queryGroupAttributes can be used to queryGroupAttributes, queryAllGroupAttributes can be used to queryAllGroupAttributes.

  • groupAttributes
  • groupID

Implementation

Future<ZIMGroupAttributesOperatedResult> setGroupAttributes(
    Map<String, String> groupAttributes, String groupID);