setGroupMemberRole abstract method

Future<ZIMGroupMemberRoleUpdatedResult> setGroupMemberRole(
  1. int role,
  2. String forUserID,
  3. String groupID
)

todo

Available since: 2.0.0 and above. Description: After a group is created, you can use this method to set the roles of group members. Use cases: The ZIM instance can be invoked after being created by create and logged in. When to call /Trigger: If the primary role of a group is 1 and the default role of other members is 3, you can invoke this interface to change the role. Caution: Non-group master unavailable. Related callbacks: Through the callback ZIMGroupMemberRoleUpdatedCallback can be set up to get the results of the group of members of the role.

  • role role
  • forUserID forUserID
  • groupID groupID

Implementation

Future<ZIMGroupMemberRoleUpdatedResult> setGroupMemberRole(
  int role,
  String forUserID,
  String groupID,
);