setRoomAttributes abstract method
- Map<
String, String> roomAttributes, - String roomID,
- ZIMRoomAttributesSetConfig config
Set room attributes (use this for all additions and changes).
Available since: 1.3.0.
Description: Used to set room properties.
Use cases: This interface is used when you need to set the mic bit in a chat room.
When to call /Trigger: after login, and in the relevant room to call.
Restrictions: You can set a maximum of 20 properties per room.
Notice: Key-value of the room property. The default key length is 16 and the default value length is 1024.
Default value: ZIMRoomAttributesSetConfig the space-time of the default configuration is optional, and do not update the owner, and involves the room properties in the owner is not automatically deleted after exit.
Privacy reminder: Try not to introduce sensitive information related to personal privacy into the property of the room, including but not limited to mobile phone number, ID number, passport number, real name, etc.
Privacy reminder: Adds or modifies room properties to an existing room.
Related callbacks: ZIMRoomAttributesOperatedCallback.
Related APIs: DeleteRoomAttributes to delete room attributes. QueryRoomAllAttributes, queries the room attributes.
roomAttributesRoom attributes to be set.roomIDTo modify the room number of the room attribute.configBehavior configuration of the operation.
Implementation
Future<ZIMRoomAttributesOperatedCallResult> setRoomAttributes(
Map<String, String> roomAttributes,
String roomID,
ZIMRoomAttributesSetConfig config);