setRoomMembersAttributes abstract method

Future<ZIMRoomMembersAttributesOperatedResult> setRoomMembersAttributes(
  1. Map<String, String> attributes,
  2. List<String> userIDs,
  3. String roomID,
  4. ZIMRoomMemberAttributesSetConfig config,
)

Set room member attributes (use this for all additions and changes).

Supported Versions: 2.4.0 and above. Detail description: Call this API to set room user properties of members in the room. Business scenario: If you need to set a level for members in the room, you can use this interface to set a state. Default: ZIMRoomMemberAttributesSetConfig Default constructor isDeleteAfterOwnerLeft is true. Call timing: After logging in and calling in the relevant room. Usage limit: A maximum of 500 user attributes can be set in each room and stored in the key-value mode. If you need to increase the attribute limit, please contact ZEGO technical support. The total length of user attribute key-values owned by each user in a room cannot exceed 144 bytes, and the number of key-values cannot exceed 30 pairs. The length of a single key-value cannot exceed 8 bytes for a Key and 64 bytes for a Value. If you need to raise the cap, please contact ZEGO technical support. After the room is destroyed, the user-defined user properties are also destroyed. Relevant callbacks: ZIMRoomMembersAttributesOperatedCallback,onRoomMemberAttributesUpdated. Related interfaces: queryRoomMembersAttributes, queryRoomMemberAttributesList.

  • attributes Room member attributes to be set.
  • userIDs A list of userIDs to set.
  • roomID Room ID.
  • config Behavior configuration of the operation.

Implementation

Future<ZIMRoomMembersAttributesOperatedResult> setRoomMembersAttributes(
    Map<String, String> attributes,
    List<String> userIDs,
    String roomID,
    ZIMRoomMemberAttributesSetConfig config);