transferGroupOwner abstract method

Future<ZIMGroupOwnerTransferredResult> transferGroupOwner(
  1. String toUserID,
  2. String groupID
)

Available since: 2.0.0 and above. Description: After a group is created, the group owner can use this method to assign the group owner to a specified user. Use cases: In a group chat scenario, you can transfer the group master through this interface. When to call /Trigger: The ZIM instance can be invoked after being created by create and logged in. Restrictions: You cannot transfer a group owner if you are not a group owner. Related APIs: Through the callback ZIMGroupOwnerTransferredCallback can get the result of the transfer of the group manager.

  • toUserID toUserID
  • groupID groupID

Implementation

Future<ZIMGroupOwnerTransferredResult> transferGroupOwner(
  String toUserID,
  String groupID,
);