updateGroupName abstract method

Future<ZIMGroupNameUpdatedResult> updateGroupName(
  1. String groupName,
  2. String groupID
)

Available since: 2.0.0 and above. Description: After a group is created, users can call this method to change the group name. Use cases: After creating a group, you need to change the group name. When to call /Trigger: The ZIM instance can be invoked after being created by create and logged in. Restrictions: Group members and group owners can change the group name. The maximum length of the name is 100 bytes. Related APIs: Through the callback ZIMGroupNameUpdatedCallback can get the result of the change of name, through onGroupNoticeUpdated can get update group name information.

  • groupName
  • groupID

Implementation

Future<ZIMGroupNameUpdatedResult> updateGroupName(
    String groupName, String groupID);