updateGroupNotice abstract method

Future<ZIMGroupNoticeUpdatedResult> updateGroupNotice(
  1. String groupNotice,
  2. String groupID
)

todo

Available since: 2.0.0 and above. Description: When a group is created, users can use this method to update the group bulletin. Use cases: You need to update the group bulletin in the group. When to call /Trigger: The ZIM instance can be invoked after being created by create and logged in. Restrictions: Only group members can update the group bulletin. The maximum number of bytes is 300. There is no special character limit. Related callbacks: Through callback ZIMGroupNoticeUpdateCallback can get update group of the results announcement, announcement by onGroupNoticeUpdated can get update group information.

  • groupNotice
  • groupID

Implementation

Future<ZIMGroupNoticeUpdatedResult> updateGroupNotice(
    String groupNotice, String groupID);