updateUserExtendedData abstract method

Future<ZIMUserExtendedDataUpdatedResult> updateUserExtendedData(
  1. String extendedData
)

Update user's user extended data.

Available since: 2.2.0 or above. Description: After user logs in, calling this interface could update the user's own user extended data. When to call: After the user is logged in. Privacy reminder: Try not to pass in sensitive information involving personal privacy, including but not limited to mobile phone numbers, ID numbers, passport numbers, real names, etc. Related callbacks: onUserNameUpdatedCallback . Related APIs: updateUserName and queryUsersInfo .

  • extendedData User extended data wanted to changed to .

Implementation

Future<ZIMUserExtendedDataUpdatedResult> updateUserExtendedData(
    String extendedData);