updateUserName abstract method

Future<ZIMUserNameUpdatedResult> updateUserName(
  1. String userName
)

Update user's user name.

Available since: 2.2.0 or above. Description: After user logs in, calling this interface could update the user's own user name. When to call: After the user is logged in. Note: This interface does not support modifying user names in rooms. Privacy reminder: Try not to pass in sensitive information involving personal privacy, including but not limited to mobile phone numbers, ID numbers, passport numbers, real names, etc. Related callbacks: ZIMUserNameUpdatedCallback. Related APIs: updateUserExtendedData and queryUsersInfo.

  • userName User name , It is customized by the developer. For version 2.0.0 and onwards, the string has a maximum length of 256 bytes.

Implementation

Future<ZIMUserNameUpdatedResult> updateUserName(String userName);