uploadLog abstract method

Future<void> uploadLog()

Upload log and call after setting up log path.

Supported version: 1.2.0 and above. Detailed description: By default, the SDK will create and print log files in the default directory of the App. By default, the maximum value of each log file is 5MB, and the three log files are written in a cycle. When this function is called, the SDK automatically packages and uploads the log file to the ZEGO server. Use case: Developers can provide business "feedback" channels in the App. When user feedback problems belong to ZEGO SDK, they can call this function to upload the local log information of SDK and contact ZEGO technical support to help locate user problems. Calling timing: It must be after calling create to create an instance. Usage Restriction: If this interface is invoked repeatedly within 10 minutes, only the last invocation takes effect. Note: If you call destory or exit the App too quickly after calling this interface to upload logs, it may fail. You are advised to wait a few seconds and then call destory or exit the App after receiving the callback for successful upload. Related callbacks: Developers can get the upload results through the callback parameter.

Implementation

Future<void> uploadLog();