ZIMCallRejectConfig class

This parameter is used to set the configuration item of call invitation rejection.

Description: This command is used to customize the call invitation when sending invitation rejection. Use cases: You need to pass the configuration item to the interface when invoking the call rejection invitation.

Constructors

ZIMCallRejectConfig({String extendedData = ''})
ZIMCallRejectConfig.fromMap(Map map)

Properties

extendedData String
Additional fields for attaching custom content when sending a reject invitation.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited