ZIMCombineMessageDetailQueriedResult class
Result callback for querying merge message details.
- message Combine message object. The messageList in this object already contains the sub-message list of the merged message.
- Available extensions
Constructors
- ZIMCombineMessageDetailQueriedResult({required ZIMCombineMessage message})
- ZIMCombineMessageDetailQueriedResult.fromMap(Map map)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message ↔ ZIMCombineMessage
-
Combine message object. The messageList in this object already contains the sub-message list of the merged message.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited