orderKey property
OrderKey is used to describe the order of messages in the session. The larger orderKey is, the newer it is.
Implementation
int orderKey;
OrderKey is used to describe the order of messages in the session. The larger orderKey is, the newer it is.
int orderKey;