ZIMConversationFilterOption class

Search filters related to the conversation.

Description: Configurable filter options when querying conversation list.

Constructors

ZIMConversationFilterOption({List<ZIMConversationType>? conversationTypes, List<int>? marks, bool isOnlyUnreadConversation = false, ZIMConversationPinnedFilter pinnedFilter = ZIMConversationPinnedFilter.all})
ZIMConversationFilterOption.fromMap(Map map)

Properties

conversationTypes List<ZIMConversationType>
Conversation type list
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isOnlyUnreadConversation bool
Whether to query only unread conversations
getter/setter pair
marks List<int>
Conversation mark list
getter/setter pair
pinnedFilter ZIMConversationPinnedFilter
Conversation pinned filter
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited