ZIMConversationPinnedFilter enum

When a user queries the session list, it serves as a filter item for the top session of the query.

Inheritance
Available extensions

Values

all → const ZIMConversationPinnedFilter

Both pinned and unpinned conversations can be queried.

onlyPinned → const ZIMConversationPinnedFilter

Only pinned conversations can be queried.

onlyUnpinned → const ZIMConversationPinnedFilter

Only unpinned conversations can be queried.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int

Available on ZIMConversationPinnedFilter, provided by the ZIMConversationPinnedFilterExtension extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ZIMConversationPinnedFilter>
A constant List of the values in this enum, in order of their declaration.