ZIMConversationsSearchedResult class

Search for the return of local conversations results based on local messages.

Available extensions

Constructors

ZIMConversationsSearchedResult({required List<ZIMConversationSearchInfo> conversationSearchInfoList, required int nextFlag})
ZIMConversationsSearchedResult.fromMap(Map map)

Properties

conversationSearchInfoList List<ZIMConversationSearchInfo>
The list of searched conversation results.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
nextFlag int
Anchor for the next page query.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited