ZIMErrorUserInfo class

Error user information class.

Description: Used to show the failed user and the reason for the failure.

Constructors

ZIMErrorUserInfo({required String userID, required int reason})
ZIMErrorUserInfo.fromMap(Map map)

Properties

hashCode int
The hash code for this object.
no setterinherited
reason int
Description Reason for the query failure.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userID String
User ID, a string with a maximum length of 32 bytes or less. It is customized by the developer. Only support numbers, English characters and '!', '#', '$', '%', '&', '(', ')', '+', '-', ':', ';', '<', '=', '.', '>', '?', '@', '', '', '^', '_', '{', '}', '|', '~'.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited