onBroadcastMessageReceived property
The callback for receiving broadcast message.
Supported version: 2.10.0 or later.
Description: The callback is received when the server interface SendMessageToAllUsers sends a message.
Call time: This callback is received after logging in to the ZIM service and the server call the SendMessageToAllUsers interface to send a message.
-
zim ZIM instance.
-
message Received message.
-
zimZIM instance. -
messageReceived broadcast message.
Implementation
static void Function(ZIM zim, ZIMMessage message)? onBroadcastMessageReceived;