onCallInvitationAccepted property

  1. @Deprecated('Deprecated since 2.9.0, pleace use [onCallUserStateChanged] instead.')
void Function(ZIM zim, ZIMCallInvitationAcceptedInfo info, String callID)? onCallInvitationAccepted
getter/setter pair

Event callback when the call invitation is accepted.

Detail description: After the invitee accepts the call invitation, this callback will be received when the inviter is online. Business scenario: The inviter will receive this callback after the inviter accepts the call invitation. When to call: After creating a ZIM instance through create. Note: This callback will not be called if the user is not online. Related interface: callAccept.

@deprecated Deprecated since 2.9.0, pleace use onCallUserStateChanged instead.

  • zim ZIM instance.
  • info Call invitation acceptance information.
  • callID Call ID.

Implementation

@Deprecated(
    'Deprecated since 2.9.0, pleace use  [onCallUserStateChanged] instead.')
static void Function(
        ZIM zim, ZIMCallInvitationAcceptedInfo info, String callID)?
    onCallInvitationAccepted;