onCallInvitationCancelled property

void Function(ZIM zim, ZIMCallInvitationCancelledInfo info, String callID)? onCallInvitationCancelled
getter/setter pair

Event callback when the call invitation is cancelled.

Supported versions: 2.0.0 and above. Business scenario: The invitee will call this callback after the inviter cancels the call invitation. When to call: After creating a ZIM instance through create. Note: If the user is not in the cancel invitation list or is offline, this callback will not be called. Related interface: callCancel.

  • zim ZIM instance.
  • info Call invitation cancellation information.
  • callID Call ID.

Implementation

static void Function(
        ZIM zim, ZIMCallInvitationCancelledInfo info, String callID)?
    onCallInvitationCancelled;