onCallInvitationTimeout property

void Function(ZIM zim, ZIMCallInvitationTimeoutInfo info, String callID)? onCallInvitationTimeout
getter/setter pair

Event callback when the call invitation times out.

Supported versions: 2.9.0 and above. Detail description: When the call invitation times out, the invitee does not respond and will receive a callback. Business scenario: If the invitee does not respond before the timeout period, this callback will be received. When to call: After creating a ZIM instance through create. Note: If the user is not on the invitation list or is not online, the callback will not be received. Related interfaces: callInvite, callAccept, callReject.

  • zim ZIM instance.
  • info Call invitation timeout information.
  • callID Call ID.

Implementation

static void Function(
        ZIM zim, ZIMCallInvitationTimeoutInfo info, String callID)?
    onCallInvitationTimeout;