onCallUserStateChanged property
Event callback when the call invitation user status changes.
Supported versions: 2.9.0 and above.
Detail description: Listen for calling user status changes.
When to call: When a new member is invited to a call, or a member accepts, rejects, exits, or a member response times out, all users on the current call invitation whose status is "Inviting," "Accepted," and "Received" receive the callback here. If the member is not online at the time of notification, the call is still ongoing when the login succeeds. The status changes of all members during the offline period will be sent to the user at one time.
Note: If the user is not the inviter who initiated this call invitation or is not online, the callback will not be received.
Related APIs: callInvite, callingInvite, callAccept, callReject,callQuit.
-
zim ZIM instance.
-
info Information about the status change of a call member.
-
Unique identifier of the call.
-
zimZIM instance. -
infoCall invitation user status change information. -
callIDCall ID.
Implementation
static void Function(ZIM zim, ZIMCallUserStateChangeInfo info, String callID)?
onCallUserStateChanged;