onConversationMessageReceiptChanged property

void Function(ZIM zim, List<ZIMMessageReceiptInfo> infos)? onConversationMessageReceiptChanged
getter/setter pair

Received notification callback when the message receiver has read this receipt message.

Available since: 2.5.0 and above. Description: When the message receiver has read the session, the message sender knows through this callback. When to call /Trigger: Trigger a notification when the message receiver has read the session. Related APIs: triggered when the peer calls via sendConversationMessageReceiptRead.

  • zim ZIM instance.
  • infos todo

Implementation

static void Function(ZIM zim, List<ZIMMessageReceiptInfo> infos)?
    onConversationMessageReceiptChanged;