onConversationsAllDeleted property
void Function(ZIM zim, ZIMConversationsAllDeletedInfo info)?
onConversationsAllDeleted
getter/setter pair
When multiple login ends delete all sessions, the local end triggers the callback to notify the local end that all sessions are deleted.
Available since: 2.12.0 and above.
Description: When multiple login ends delete all sessions, the local end triggers the callback to notify the local end that all sessions are deleted.
When to call /Trigger: When another end clears all unread sessions, the local end triggers a notification.
Related APIs: Triggered by deleteAllConversations.
zimZIM instance.infotodo
Implementation
static void Function(ZIM zim, ZIMConversationsAllDeletedInfo info)?
onConversationsAllDeleted;