onMessageReceiptChanged property

void Function(ZIM zim, List<ZIMMessageReceiptInfo> infos)? onMessageReceiptChanged
getter/setter pair

Received notification callback when the message receiver confirms that the message has been read.

Available since: 2.5.0 and above. Description: When the message receiver confirms that the message has been read, the message sender knows through this callback. When to call /Trigger: Trigger a notification when the message receiver has read the message. Related APIs: Triggered when the peer calls via sendMessageReceiptsRead.

  • zim ZIM instance.
  • infos List of message receipt change information.

Implementation

static void Function(ZIM zim, List<ZIMMessageReceiptInfo> infos)?
    onMessageReceiptChanged;