onRoomStateChanged property

void Function(ZIM zim, ZIMRoomState state, ZIMRoomEvent event, Map extendedData, String roomID)? onRoomStateChanged
getter/setter pair

The event callback when the room connection status changes.

Description:event callback when the room connection status changes. When to call::After creating a ZIM instance through create, you can call this interface. Related APIs:through onTokenWillExpire, the callback will be received when the token is about to expire.

  • zim ZIM instance.
  • state Room state.
  • event Room event.
  • extendedData Extended data.
  • roomID Room ID.

Implementation

static void Function(ZIM zim, ZIMRoomState state, ZIMRoomEvent event,
    Map extendedData, String roomID)? onRoomStateChanged;