onTokenWillExpire property
A reminder callback that the token is about to expire.
zimZIM instance.secondThe remaining second before the token expires.
Implementation
static void Function(ZIM zim, int second)? onTokenWillExpire;
A reminder callback that the token is about to expire.
zim ZIM instance.second The remaining second before the token expires.static void Function(ZIM zim, int second)? onTokenWillExpire;