onUserInfoUpdated property

void Function(ZIM zim, ZIMUserFullInfo info)? onUserInfoUpdated
getter/setter pair

In the multi-terminal login scenario, after the user modifies their information on device A, other online multi-terminal devices will receive this callback. For offline devices, after the user goes online, they need to call the ZIM.QueryUsersInfo interface to actively query user information.

  • zim ZIM instance.
  • info The user info after updating.

Implementation

static void Function(ZIM zim, ZIMUserFullInfo info)? onUserInfoUpdated;