ZIMFriendApplicationInfo class

Friend application information.

Description: Detailed description: Friend application information.

Constructors

ZIMFriendApplicationInfo({required ZIMFriendApplicationType type, required ZIMFriendApplicationState state, required ZIMUserInfo applyUser, required String wording, required int createTime, required int updateTime})
ZIMFriendApplicationInfo.fromMap(Map map)

Properties

applyUser ZIMUserInfo
Detail description: If you are the applicant, here is the respondent information; if you are the respondent, here is the applicant information;.
getter/setter pair
createTime int
Friend add time.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state ZIMFriendApplicationState
Friend application state.
getter/setter pair
type ZIMFriendApplicationType
Friend application type.
getter/setter pair
updateTime int
Friend application status update time.
getter/setter pair
wording String
The wording of friend application information.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited