ZIMFriendApplicationListQueriedResult class

The result of sending a friend application.

  • applicationList Friend application information list.
  • nextFlag Pagination flag, used to get the next page. The current value returns 0, indicating that all data has been pulled out.
Available extensions

Properties

applicationList List<ZIMFriendApplicationInfo>
Friend application information list.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
nextFlag int
Pagination flag, used to get the next page. The current value returns 0, indicating that all data has been pulled out.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited