ZIMGroupAttributesQueriedResult class
The return of query group attribute results.
- groupID Group ID.
- groupAttributes Group attributes.
- Available extensions
Constructors
-
ZIMGroupAttributesQueriedResult({required String groupID, required Map<
String, String> groupAttributes}) - ZIMGroupAttributesQueriedResult.fromMap(Map map)
Properties
-
groupAttributes
↔ Map<
String, String> -
Group attributes.
getter/setter pair
- groupID ↔ String
-
Group ID.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited