ZIMGroupConversation class
todo
todo
- Inheritance
-
- Object
- ZIMConversation
- ZIMGroupConversation
Constructors
- ZIMGroupConversation({bool isDisabled = false, int mutedExpiredTime = 0})
- ZIMGroupConversation.fromMap(Map map)
Properties
- conversationAlias ↔ String
-
todo
getter/setter pairinherited
- conversationAvatarUrl ↔ String
-
getter/setter pairinherited
- conversationID ↔ String
-
getter/setter pairinherited
- conversationName ↔ String
-
getter/setter pairinherited
- draft ↔ String
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDisabled ↔ bool
-
getter/setter pair
- isPinned ↔ bool
-
getter/setter pairinherited
- lastMessage ↔ ZIMMessage?
-
getter/setter pairinherited
-
marks
↔ List<
int> -
getter/setter pairinherited
-
mentionedInfoList
↔ List<
ZIMMessageMentionedInfo> -
getter/setter pairinherited
- mutedExpiredTime ↔ int
-
getter/setter pair
- notificationStatus ↔ ZIMConversationNotificationStatus
-
getter/setter pairinherited
- orderKey ↔ int
-
getter/setter pairinherited
- pinnedTime ↔ int
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ ZIMConversationType
-
getter/setter pairinherited
- unreadMessageCount ↔ int
-
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited