ZIMGroupEnterInfo class

Group entry information

todo

Constructors

ZIMGroupEnterInfo({int enterTime = 0, ZIMGroupEnterType enterType = ZIMGroupEnterType.unknown, ZIMGroupMemberSimpleInfo? operatedUser})
ZIMGroupEnterInfo.fromMap(Map map)

Properties

enterTime int
getter/setter pair
enterType ZIMGroupEnterType
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
operatedUser ZIMGroupMemberSimpleInfo?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited