ZIMGroupInfo class

todo

todo

Constructors

ZIMGroupInfo({String groupID = '', String groupName = '', String groupAvatarUrl = ''})
ZIMGroupInfo.fromMap(Map map)

Properties

groupAvatarUrl String
getter/setter pair
groupID String
getter/setter pair
groupName String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited