ZIMGroupMemberInfo class
todo
todo
- Inheritance
-
- Object
- ZIMUserInfo
- ZIMGroupMemberInfo
Constructors
- ZIMGroupMemberInfo({String userID = "", String userName = "", String userAvatarUrl = "", String memberNickname = '', int memberRole = 0, String memberAvatarUrl = '', int muteExpiredTime = 0, ZIMGroupEnterInfo? groupEnterInfo})
- ZIMGroupMemberInfo.fromMap(Map map)
Properties
- groupEnterInfo ↔ ZIMGroupEnterInfo?
-
todo
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- memberAvatarUrl ↔ String
-
getter/setter pair
- memberNickname ↔ String
-
getter/setter pair
- memberRole ↔ int
-
getter/setter pair
- muteExpiredTime ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userAvatarUrl ↔ String
-
User avatar URL
getter/setter pairinherited
- userExtendedData ↔ String
-
User extended data. This field is currently only available in room related interfaces.
getter/setter pairinherited
- userID ↔ String
-
User ID, a string with a maximum length of 32 bytes or less. It is customized by the developer. Only support numbers, English characters and '!', '#', '$', '%', '&', '(', ')', '+', '-', ':', ';', '<', '=', '.', '>', '?', '@', '
', '', '^', '_', '{', '}', '|', '~'.getter/setter pairinherited - userName ↔ String
-
Description: User name, defined by you. For version 2.0.0 and onwards, the string has a maximum length of 256 bytes.Required: Not required.Privacy reminder: Please do not provide sensitive personal information, including but not limited to mobile phone numbers, ID card numbers, passport numbers, and real names.
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited