ZIMGroupMemberRoleUpdatedResult class

todo

Available extensions

Constructors

ZIMGroupMemberRoleUpdatedResult({required String groupID, required String forUserID, required int role})
ZIMGroupMemberRoleUpdatedResult.fromMap(Map map)

Properties

forUserID String
User ID.
getter/setter pair
groupID String
Group ID.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
role int
User role.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited