ZIMGroupMutedResult class

todo

Available extensions

Constructors

ZIMGroupMutedResult({required String groupID, required bool isMute, required ZIMGroupMuteInfo mutedInfo})
ZIMGroupMutedResult.fromMap(Map map)

Properties

groupID String
Group ID.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isMute bool
Whether to mute.
getter/setter pair
mutedInfo ZIMGroupMuteInfo
Group mute information.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited