ZIMGroupUsersInvitedResult class

todo

Available extensions

Constructors

ZIMGroupUsersInvitedResult({required String groupID, required List<ZIMGroupMemberInfo> userList, required List<ZIMErrorUserInfo> errorUserList})
ZIMGroupUsersInvitedResult.fromMap(Map map)

Properties

errorUserList List<ZIMErrorUserInfo>
Error member list.
getter/setter pair
groupID String
Group ID.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userList List<ZIMGroupMemberInfo>
Group member information list.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited