nextFlag property
Used to query the next page. The current value returns 0, which means that the list has been pulled out.
Implementation
int nextFlag;
Used to query the next page. The current value returns 0, which means that the list has been pulled out.
int nextFlag;