largeImageDownloadUrl property

String largeImageDownloadUrl
getter/setter pair

Detail description: large Image external download URL of the image file. When developers upload large Images to their own servers, the SDK can pass through this field to other users.Required or not: optional on the sender side, this field will only take effect when fileDownloadUrl is filled in.

Implementation

String largeImageDownloadUrl;