ZIMLogConfig class

Log configuration

Description: Configure the storage path of log files and the maximum log file size.

Constructors

ZIMLogConfig({String logPath = '', int logSize = 5242880, int? logLevel})
ZIMLogConfig.fromMap(Map map)

Properties

hashCode int
The hash code for this object.
no setterinherited
logLevel int?
Description: Log level, only used on the web platform. Required: Not required. Default value: 0.
getter/setter pair
logPath String
The storage path of the log files. Refer to the official website document for the default path.
getter/setter pair
logSize int
The maximum log file size (Bytes). The default maximum size is 5MB (5 * 1024 * 1024 Bytes)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited