fileDownloadUrl property

String fileDownloadUrl
getter/setter pair

Detail description: The external download url of the media message is used for the developer to transparently transmit the media file to other users by filling in this URL when the developer uploads the media file to his own server.Required or not: If an external URL is sent, this parameter is mandatory on the sender end.

Implementation

String fileDownloadUrl;