fileName property

String fileName
getter/setter pair

Detail description: The filename of the media file. Required or not: If you are sending an external URL, you need to fill in this value and include the file extension. If a local file is sent, the value is optional.

Implementation

String fileName;