fileSize property
Detail description: The size of the media file. Required or not: The sender does not need to fill in, this value is generated by the SDK.
Implementation
int fileSize;
Detail description: The size of the media file. Required or not: The sender does not need to fill in, this value is generated by the SDK.
int fileSize;