fileUID property
Detail description: The unique ID of the media file. Required or not: The sender does not need to fill in, this value is generated by the SDK.
Implementation
String fileUID;
Detail description: The unique ID of the media file. Required or not: The sender does not need to fill in, this value is generated by the SDK.
String fileUID;