conversationType property
Description: The type of conversation to which the message belongs.
Implementation
ZIMConversationType conversationType;
Description: The type of conversation to which the message belongs.
ZIMConversationType conversationType;