extendedData property

String extendedData
getter/setter pair

Description: message extension field Use cases: You can add extended fields to the message and send it to the peer Required: no Caution:the length is 1k, you can contact technical support for configuration Available since: 2.6.0 or higher

Implementation

String extendedData;