isUserInserted property
Detail description: Describes whether the message is a message inserted by the developer through insertMessageToLocalDB.Default: false.
Implementation
bool isUserInserted;
Detail description: Describes whether the message is a message inserted by the developer through insertMessageToLocalDB.Default: false.
bool isUserInserted;