orderKey property
Description:The larger the orderKey, the newer the message, and can be used for ordering messages.
Implementation
int orderKey;
Description:The larger the orderKey, the newer the message, and can be used for ordering messages.
int orderKey;