reactions property
Description: Message statement list, which can carry data strongly related to users such as emoji expressions and voting information.
Implementation
List<ZIMMessageReaction> reactions;
Description: Message statement list, which can carry data strongly related to users such as emoji expressions and voting information.
List<ZIMMessageReaction> reactions;