receiptStatus property
Detailed Description: Describe the receipt status of the messageBusiness scenario: used to determine the status of the current message in the receipt message
Implementation
ZIMMessageReceiptStatus receiptStatus;
Detailed Description: Describe the receipt status of the messageBusiness scenario: used to determine the status of the current message in the receipt message
ZIMMessageReceiptStatus receiptStatus;