ZIMMessageReaction class

message reaction infos

Description: message reaction infos.

Constructors

ZIMMessageReaction({required String reactionType, required String conversationID, required ZIMConversationType conversationType, required dynamic messageID, required int totalCount, required bool isSelfIncluded, required List<ZIMMessageReactionUserInfo> userList, required int sumCount})
ZIMMessageReaction.fromMap(Map map)

Properties

conversationID String
Description: conversationID.
getter/setter pair
conversationType ZIMConversationType
Description: conversation type.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isSelfIncluded bool
Description: The reaciton users if included myself.
getter/setter pair
messageID ↔ dynamic
Detail description: reaction message ID.
getter/setter pair
reactionType String
Description: Type of reaction, defined by you, with a maximum length of 32 bytes.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sumCount int
Detailed description: The sum count of reaction.
getter/setter pair
totalCount int
Description: The reaction users number.
getter/setter pair
userList List<ZIMMessageReactionUserInfo>
Description: Reaction user info list.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited