ZIMMessageReactionUserListQueriedResult class
todo
- message Message object.
- userInfoList List of user reaction information.
- reactionType Message reaction type.
- nextFlag List query anchor, used to query the next page. The current value returns 0, which means that the list has been pulled out.
- totalCount Total user count.
- Available extensions
Constructors
-
ZIMMessageReactionUserListQueriedResult({required ZIMMessage message, required List<
ZIMMessageReactionUserFullInfo> userInfoList, required String reactionType, required int nextFlag, required int totalCount, required List<ZIMMessageReactionUserInfo> userList}) - ZIMMessageReactionUserListQueriedResult.fromMap(Map map)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message ↔ ZIMMessage
-
Message object.
getter/setter pair
- nextFlag ↔ int
-
List query anchor, used to query the next page. The current value returns 0, which means that the list has been pulled out.
getter/setter pair
- reactionType ↔ String
-
Message reaction type.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalCount ↔ int
-
Total user count.
getter/setter pair
-
userInfoList
↔ List<
ZIMMessageReactionUserFullInfo> -
List of user reaction information.
getter/setter pair
-
userList
↔ List<
ZIMMessageReactionUserInfo> -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited