ZIMMessageReceiptsInfoQueriedResult class
todo
- infos Message receipt information list.
- errorMessageIDs Error message ID list.
- Available extensions
Constructors
-
ZIMMessageReceiptsInfoQueriedResult({required List<
ZIMMessageReceiptInfo> infos, required List errorMessageIDs}) - ZIMMessageReceiptsInfoQueriedResult.fromMap(Map map)
Properties
- errorMessageIDs ↔ List
-
Error message ID list.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
infos
↔ List<
ZIMMessageReceiptInfo> -
Message receipt information list.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited