ZIMMessageReceiptsReadSentResult class
todo
- conversationID Conversation ID.
- conversationType Conversation type.
- errorMessageIDs Error message ID list.
- Available extensions
Constructors
- ZIMMessageReceiptsReadSentResult({required String conversationID, required ZIMConversationType conversationType, required List errorMessageIDs})
- ZIMMessageReceiptsReadSentResult.fromMap(Map map)
Properties
- conversationID ↔ String
-
Conversation ID.
getter/setter pair
- conversationType ↔ ZIMConversationType
-
Conversation type.
getter/setter pair
- errorMessageIDs ↔ List
-
Error message ID list.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited