hasReceipt property

bool hasReceipt
getter/setter pair

Detailed description: When sending a message, whether the message has a receipt.Business scenario: use when you need to bring a receipt for a message.Required: not required.Default value: false.

Implementation

bool hasReceipt;