pushConfig property

ZIMPushConfig? pushConfig
getter/setter pair

Description: Configures the offline push function, If Android or iOS platform is integrated, it is strongly recommended to configure this. Required: Not mandatory.

Implementation

ZIMPushConfig? pushConfig;