onMessageAttached property

ZIMMessageAttachedCallback? onMessageAttached
getter/setter pair

Detail description: After the message falls into the local DB, the notification will be called back before the message is sent to the server. Business scenario: This interface can be used when the developer needs to obtain the relevant information in the message in advance before sending the message. Required: not required. If no monitoring is required, it can be passed empty. Default: empty.

Implementation

ZIMMessageAttachedCallback? onMessageAttached;