ZIMMessagesSearchedResult class

todo

Available extensions

Constructors

ZIMMessagesSearchedResult({required String conversationID, required ZIMConversationType conversationType, required List<ZIMMessage> messageList, ZIMMessage? nextMessage})
ZIMMessagesSearchedResult.fromMap(Map map)

Properties

conversationID String
Conversation ID.
getter/setter pair
conversationType ZIMConversationType
Conversation type.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
messageList List<ZIMMessage>
Message list.
getter/setter pair
nextMessage ZIMMessage?
Next message object.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited