privateMessageTemplate property
Description: If you use OPPO Push, you can carry the push template through this field.
Implementation
ZIMOfflinePushPrivateMessageTemplate? privateMessageTemplate;
Description: If you use OPPO Push, you can carry the push template through this field.
ZIMOfflinePushPrivateMessageTemplate? privateMessageTemplate;