ZIMRoomAttributesQueriedResult class

todo

Available extensions

Constructors

ZIMRoomAttributesQueriedResult({required String roomID, required Map<String, String> roomAttributes})
ZIMRoomAttributesQueriedResult.fromMap(Map map)

Properties

hashCode int
The hash code for this object.
no setterinherited
roomAttributes Map<String, String>
Room attributes.
getter/setter pair
roomID String
Room ID.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited