ZIMRoomMemberAttributesListQueriedResult class

todo

  • roomID Room ID.
  • infos Room member attribute information list.
  • nextFlag Used to query the next page. The current value returns 0, which means that the list has been pulled out.
Available extensions

Properties

hashCode int
The hash code for this object.
no setterinherited
infos List<ZIMRoomMemberAttributesInfo>
Room member attribute information list.
getter/setter pair
nextFlag String
Used to query the next page. The current value returns 0, which means that the list has been pulled out.
getter/setter pair
roomID String
Room ID.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited