ZIMRoomMemberInfo class

Room user information.

Detail description: A class describing room user.

Inheritance

Constructors

ZIMRoomMemberInfo({String userID = "", String userName = "", String userAvatarUrl = ""})
ZIMRoomMemberInfo.fromMap(Map map)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userAvatarUrl String
User avatar URL
getter/setter pairinherited
userExtendedData String
User extended data. This field is currently only available in room related interfaces.
getter/setter pairinherited
userID String
User ID, a string with a maximum length of 32 bytes or less. It is customized by the developer. Only support numbers, English characters and '!', '#', '$', '%', '&', '(', ')', '+', '-', ':', ';', '<', '=', '.', '>', '?', '@', '', '', '^', '_', '{', '}', '|', '~'.
getter/setter pairinherited
userName String
Description: User name, defined by you. For version 2.0.0 and onwards, the string has a maximum length of 256 bytes.Required: Not required.Privacy reminder: Please do not provide sensitive personal information, including but not limited to mobile phone numbers, ID card numbers, passport numbers, and real names.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited