ZIMRoomMembersAttributesOperatedResult class
todo
- roomID Room ID.
- infos Room member attribute operation information list.
- errorUserList Error member list.
- Available extensions
Constructors
-
ZIMRoomMembersAttributesOperatedResult({required String roomID, required List<
ZIMRoomMemberAttributesOperatedInfo> infos, required List<String> errorUserList}) - ZIMRoomMembersAttributesOperatedResult.fromMap(Map map)
Properties
-
errorUserList
↔ List<
String> -
Error member list.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
infos
↔ List<
ZIMRoomMemberAttributesOperatedInfo> -
Room member attribute operation information list.
getter/setter pair
- roomID ↔ String
-
Room ID.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited