ZIMTipsMessageChangeInfoType enum

Type of additional information for tips messages.

Inheritance
Available extensions

Values

unknown → const ZIMTipsMessageChangeInfoType

Unknown change info type.

groupDataChanged → const ZIMTipsMessageChangeInfoType

Group name, group avatar, and group notice have multiple changes.

groupNoticeChanged → const ZIMTipsMessageChangeInfoType

Group notice change event.

groupNameChanged → const ZIMTipsMessageChangeInfoType

Group name change event.

groupAvatarUrlChanged → const ZIMTipsMessageChangeInfoType

Group avatar change event.

groupMuteChanged → const ZIMTipsMessageChangeInfoType

Group mute info change event.

groupOwnerTransferred → const ZIMTipsMessageChangeInfoType

Group owner transfer event.

groupMemberRoleChanged → const ZIMTipsMessageChangeInfoType

Group member role change event.

groupMemberMuteChanged → const ZIMTipsMessageChangeInfoType

The group member mute status changed.

groupMessagePinInfoChanged → const ZIMTipsMessageChangeInfoType

Group messages are pinned or unpinned event.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int

Available on ZIMTipsMessageChangeInfoType, provided by the ZIMTipsMessageChangeInfoTypeExtension extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ZIMTipsMessageChangeInfoType>
A constant List of the values in this enum, in order of their declaration.