ZIMUserFullInfo class

User full information object.

Description: Identifies a unique user. Caution: Note that the userID must be unique under the same appID, otherwise mutual kicks out will occur.It is strongly recommended that userID corresponds to the user ID of the business APP,that is, a userID and a real user are fixed and unique, and should not be passed to the SDK in a random userID.Because the unique and fixed userID allows ZEGO technicians to quickly locate online problems.

Constructors

ZIMUserFullInfo({required ZIMUserInfo baseInfo, required String userAvatarUrl, required String extendedData})
ZIMUserFullInfo.fromMap(Map map)

Properties

baseInfo ZIMUserInfo
Description: User basic information.
getter/setter pair
extendedData String
Detailed description: User extended information.Required: not required.Privacy Protection Statement: Do not pass in sensitive information involving personal privacy, including but not limited to mobile phone numbers, ID numbers, passport numbers, real names, etc.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userAvatarUrl String
Detail description: User avatar URL.Required: not required.Use restrictions: The value is a maximum of 500 bytes and contains no special characters.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited