isQueryFromServer property

bool isQueryFromServer
getter/setter pair

Detail description: Whether to query user details from the server. Query the unlimited frequency constraints from the local, and query the limited frequency constraints from the server. You can only query the detailed configuration of 10 users within 10 s.Required: not required.Default: false.

Implementation

bool isQueryFromServer;