beginRoomAttributesBatchOperation abstract method
void
beginRoomAttributesBatchOperation(
- String roomID,
- ZIMRoomAttributesBatchOperationConfig config
Open combination room attribute operation.
Available since: 1.3.0. Description: Used to turn on the combination of room attributes.
roomIDThe number of the room where the combined operation needs to be turned on.configThe configuration of the combined operation.
Implementation
void beginRoomAttributesBatchOperation(
String roomID, ZIMRoomAttributesBatchOperationConfig config);