callAccept abstract method
Supported versions: 2.0.0 and above.
Detail description: When the calling party initiates a call invitation, the called party can accept the call invitation through this interface.
Service scenario: When you need to accept the call invitation initiated earlier, you can accept the call invitation through this interface.
When to call: It can be called after creating a ZIM instance through create.
Note: The callee will fail to accept an uninvited callid.
-
callID The call invitation ID to accept.
-
config config.
-
callback Callback to accept call invitation.
-
callIDcallID -
configconfig
Implementation
Future<ZIMCallAcceptanceSentResult> callAccept(
String callID,
ZIMCallAcceptConfig config,
);