callCancel abstract method
Future<ZIMCallCancelSentResult>
callCancel(
- List<
String> invitees, - String callID,
- ZIMCallCancelConfig config
Supported versions: 2.0.0 and above. Detail description: After the caller initiates a call invitation, the call invitation can be canceled through this interface before the timeout period. Business scenario: When you need to cancel the call invitation initiated before, you can cancel the call invitation through this interface. When to call: It can be called after creating a ZIM instance through create. Note: Canceling the call invitation after the timeout period of the call invitation expires will fail.
inviteescallIDconfig
Implementation
Future<ZIMCallCancelSentResult> callCancel(
List<String> invitees, String callID, ZIMCallCancelConfig config);