callInvite abstract method
Supported versions: 2.0.0 and above. Detail description: When the caller initiates a call invitation, the called party can use callAccept to accept the call invitation or callReject to reject the invitation. Business scenario: When you need to initiate a call invitation, you can create a unique callid through this interface to maintain this call invitation. When to call: It can be called after creating a ZIM instance through create. Note: The call invitation has a timeout period, and the call invitation will end when the timeout period expires.
inviteesinviteesconfigconfig
Implementation
Future<ZIMCallInvitationSentResult> callInvite(
List<String> invitees,
ZIMCallInviteConfig config,
);