callQuit abstract method
Supported versions: 2.9.0 and above.
Detail description: When the Lord's call initiates the invitation and is called and accepts it, the current call can be exited through the interface.
When to call: It can be called after creating a ZIM instance through create.
Note: The callee will fail to quit the uninvited callid.
Related callbacks: ZIMCallQuitSentCallback.
callIDcallIDconfigconfig
Implementation
Future<ZIMCallQuitSentResult> callQuit(
String callID,
ZIMCallQuitConfig config,
);