callReject abstract method
Reject the call invitation.
Available since: 2.0.0 and above. Description: When the calling party initiates a call invitation, the called party can reject the call invitation through this interface. Use cases: When you need to reject the call invitation initiated earlier, you can use this interface to reject the call invitation. When to call: It can be called after creating a ZIM instance through create. Caution: The callee will fail to reject the uninvited callid. Related callbacks: ZIMCallRejectionSentResult.
callIDThe ID of the call invitation to be rejected.configRelated configuration for rejecting call invitations.
Implementation
Future<ZIMCallRejectionSentResult> callReject(
String callID,
ZIMCallRejectConfig config,
);