clearConversationTotalUnreadMessageCount abstract method
clear all conversations unreads.
Available since: 2.12.0 and above.
Description: Used to clear unread for all conversations.
Use cases: You can call this interface when you need to clear all unread conversations to zero.
When to call /Trigger: Called when all conversation readings need to be cleared.
Restrictions: Valid after login, invalid after logout.
Related callbacks:ZIMConversationTotalUnreadMessageCountClearedCallback.
Impacts on other APIs: Calling this method will trigger a total readings not updated callback onConversationTotalUnreadMessageCountUpdated.
Related APIs:onConversationTotalUnreadMessageCountUpdated.
Implementation
Future<void> clearConversationTotalUnreadMessageCount();