clearLocalFileCache abstract method
Clear the local message cache of the current user.
Supported versions: 2.15.0 and above.
Detail description: Clear the local message cache of the current user.
Business scenario: This interface is invoked when the local message cache needs to be cleared.
Restrictions: This takes effect after the login and becomes invalid after the logout.
Related callbacks: ZIMFileCacheClearedCallback.
configClear the cache configuration.
Implementation
Future<void> clearLocalFileCache(ZIMFileCacheClearConfig config);