createGroup abstract method
- ZIMGroupInfo groupInfo,
- List<
String> userIDs, [ - ZIMGroupAdvancedConfig? config
Create a group with the andvanced info such as group attributes and group notice.
Available since: 2.0.0 and above.
Description: You can call this interface to create a group, and the person who calls this interface is the group leader.
Use cases: You can use this interface to create a chat scenario and join a group.
When to call /Trigger: The ZIM instance can be invoked after being created by create and logged in.
Caution: Available after login, unavailable after logout. UserIDs can have a maximum of 100 users and a group can have a maximum of 500 users.
Related callbacks: The result of creating the group is obtained through the ZIMGroupCreatedCallback callback.
Related APIs: You can use joinGroup to join a group, leaveGroup to leave a group, or dismissGroup to dismiss a group.
groupInfoConfiguration information for the group to be created.userIDsList of users invited to the group.configCreate the relevant configuration of the group.
Implementation
Future<ZIMGroupCreatedResult> createGroup(
ZIMGroupInfo groupInfo,
List<String> userIDs, [
ZIMGroupAdvancedConfig? config,
]);