deleteAllConversationMessages abstract method
Delete all messages for all conversations.
Supported versions: 2.14.0 and above.
Detail description: This method implements the function of deleting all messages for all conversations.
Business scenario: The user needs to delete a message. When the user does not need to display a message, this method can be used to delete it.
Call timing/Notify timing: Effective after login, invalid after logout.
Note: IsAlsoDeleteServerMessage decided whether to delete a server message, the impact of deleting messages is limited to this account.
Impacts on other APIs: Call the interface trigger onMessageDeleted callback, if there are unread messages at this time, will trigger onConversationTotalUnreadMessageCountUpdated callback.
Related callbacks: ZIMConversationMessagesAllDeletedCallback、onMessageDeleted、onConversationTotalUnreadMessageCountUpdated.
configdelete message configuration.
Implementation
Future<void> deleteAllConversationMessages(ZIMMessageDeleteConfig config);