deleteConversation abstract method
Future<ZIMConversationDeletedResult>
deleteConversation(
- String conversationID,
- ZIMConversationType conversationType,
- ZIMConversationDeleteConfig config
delete the conversation.
Available since: 2.0.0 and above.
Description: This interface is invoked when a session needs to be deleted. All members in the session can invoke this interface.
Use cases: You can invoke this interface implementation to delete an entire session when it is no longer needed.
When to call /Trigger: his parameter is invoked when a session needs to be deleted and can be invoked after a ZIM instance is created. The call takes effect after login and becomes invalid after logout.
Impacts on other APIs: call success will trigger onConversationchanged callback, if the deleted session include unread message triggers onConversationTotalUnreadMessageCountUpdated callback.
Related callbacks: ZIMConversationDeletedCallback
conversationIDconversationID.conversationTypeconversationtype.configdelete the session's configuration.
Implementation
Future<ZIMConversationDeletedResult> deleteConversation(String conversationID,
ZIMConversationType conversationType, ZIMConversationDeleteConfig config);