deleteMessages abstract method
- List<
ZIMMessage> messageList, - String conversationID,
- ZIMConversationType conversationType,
- ZIMMessageDeleteConfig config,
delete message.
Supported versions: 2.0.0 and above.
Detail description: This method implements the function of deleting messages.
Business scenario: The user needs to delete a message. When the user does not need to display a message, this method can be used to delete it.
Call timing/Notification timing: Called when the message needs to be deleted.
Note: The impact of deleting messages is limited to this account.
Restrictions: Effective after login.
Impacts on other APIs: If the deleted message is the latest message of the session, the conversationChanged callback will be triggered, and if the message is unread, the conversationTotalUnreadMessageCountUpdated callback will be triggered.
Related callbacks:ZIMMessageDeletedCallback、conversationChanged、conversationTotalUnreadMessageCountUpdated.
messageListList of deleted messages.conversationIDThe session ID of the deleted message.conversationTypeconversation type.configDelete the configuration of the message.
Implementation
Future<ZIMMessageDeletedResult> deleteMessages(
List<ZIMMessage> messageList,
String conversationID,
ZIMConversationType conversationType,
ZIMMessageDeleteConfig config);