deleteRoomAttributes abstract method
Future<ZIMRoomAttributesOperatedCallResult>
deleteRoomAttributes(
- List<
String> keys, - String roomID,
- ZIMRoomAttributesDeleteConfig config
Delete room attributes.
Available since: 1.3.0. Description: Used to delete room attributes.
keysThe key of the room attribute to be deleted.roomIDTo modify the room number of the room attributeconfigBehavior configuration of the operation.
Implementation
Future<ZIMRoomAttributesOperatedCallResult> deleteRoomAttributes(
List<String> keys, String roomID, ZIMRoomAttributesDeleteConfig config);