endRoomAttributesBatchOperation abstract method
Complete the property operation of the combined room.
Available since: 1.3.0. Description: After completing the operation of combining room attributes, all the setting/deleting operations from the last call to beginRoomAttributesBatchOperation to this operation will be completed for the room.
roomIDTo modify the room number of the room attribute.
Implementation
Future<ZIMRoomAttributesBatchOperatedResult> endRoomAttributesBatchOperation(
String roomID);