leaveAllRoom abstract method
Leave all rooms.
Available since: 2.15.0 or above.
Description: Call this interface to exit all rooms you have entered at once.
When to call: After creating a ZIM instance via create, it can be called when the user is in the room.
Caution: If the current user is not in this room, leaving will fail; and calling this interface can only leave the room entered under the current terminal, and will not affect the rooms entered by other terminals with multi-terminal login.
Related callbacks: The result of leaving the room can be obtained through the ZIMRoomAllLeftCallback callback.
Implementation
Future<ZIMRoomAllLeftResult> leaveAllRoom();