leaveRoom abstract method
Leave a room.
Available since: 1.1.0 or above.
Description: When the user in the room needs to leave the room, use leaveRoom to leave the room. If the room does not exist, the leave fails.
Use cases: In the multi-person chat scenario, when users in the room need to leave the room, they can leave the room through this interface.
When to call: After creating a ZIM instance via create, it can be called when the user is in the room.
Caution: If the current user is not in this room, the exit fails. When everyone leaves the room, the room will be automatically destroyed.
Related callbacks: The result of leaving the room can be obtained through the ZIMRoomLeftCallback callback.
Related APIs: You can create a room through createRoom and join a room with joinRoom.
roomIDID of the room to leave.
Implementation
Future<ZIMRoomLeftResult> leaveRoom(String roomID);