queryGroupInfo abstract method
todo
Available since: 2.0.0 and above.
Description: Query information about a created group.
Use cases: You need to obtain group information for display.
When to call /Trigger: The ZIM instance can be invoked after being created by create and logged in.
Related callbacks: Through the callback ZIMGroupInfoQueriedCallback can query the result of the group information.
-
groupID The group ID of the group information to be queried.
-
callback Callback for the result of querying group information.
-
groupID
Implementation
Future<ZIMGroupInfoQueriedResult> queryGroupInfo(String groupID);