queryGroupList abstract method
Query the group list.
Available since: 2.27.0 and above. Description: Query the list of all groups. Use cases: You need to get a list of groups to display. When to call: The ZIM instance can be invoked after being created by create and logged in. Restrictions: Available after login, unavailable after logout. Related callbacks: Through the callback ZIMGroupListQueriedResult can get a check list of all current group results.
countThe number of groups to query.configGroup list query configuration.
Implementation
Future<ZIMGroupListQueriedResult> queryGroupList({
int? count,
ZIMGroupListQueryConfig? config,
});