queryGroupList abstract method

Future<ZIMGroupListQueriedResult> queryGroupList()

Available since: 2.0.0 and above.

Description: Query the list of all groups.

Use cases: You need to get a list of groups to display.

When to call /Trigger: The ZIM instance can be invoked after being created by create and logged in.

Restrictions: Available after login, unavailable after logout.

Related callbacks: Through the callback ZIMGroupMemberListQueiedCallback can get a check list of all current group results.

  • callback A callback for querying the result of the group list.

Implementation

Future<ZIMGroupListQueriedResult> queryGroupList();