queryHistoryMessage abstract method
Future<ZIMMessageQueriedResult>
queryHistoryMessage(
- String conversationID,
- ZIMConversationType conversationType,
- ZIMMessageQueryConfig config
Query historical messages.
Supported versions: 2.0.0 and above.
Detailed description: This method is used to query historical messages.
Business scenario: When you need to obtain past historical messages, you can call this interface to query historical messages by paging.
Call timing/Notification timing: Called when historical messages need to be queried.
Restrictions: Effective after login, invalid after logout. In the default room scenario (conversationType=1), offline message is disabled. If you need to enable it, please contact the corresponding technical support.
Related callbacks: ZIMMessageQueriedCallback.
conversationIDThe session ID of the queried historical message.conversationTypeconversation type.configQuery the configuration of historical messages.
Implementation
Future<ZIMMessageQueriedResult> queryHistoryMessage(String conversationID,
ZIMConversationType conversationType, ZIMMessageQueryConfig config);