queryRoomMemberAttributesList abstract method
Future<ZIMRoomMemberAttributesListQueriedResult>
queryRoomMemberAttributesList(
- String roomID,
- ZIMRoomMemberAttributesQueryConfig config
paginate the room user properties that have room property members in the room.
Available since: 2.4.0 or later. Description: paginate the room user properties that have room property members in the room. Use cases: This interface is used when you need to query all room users. Restrictions: The maximum call frequency is 5 times within 30 seconds by default, and the maximum query time is 100 people. Related callbacks: ZIMRoomMemberAttributesListQueriedResult. Related APIs: setRoomMembersAttributes、queryRoomMembersAttributes. Life cycle: It is available after logging in and joining the corresponding room, but unavailable after leaving the corresponding room.
roomIDRoom ID.configBehavior configuration of the operation.
Implementation
Future<ZIMRoomMemberAttributesListQueriedResult>
queryRoomMemberAttributesList(
String roomID,
ZIMRoomMemberAttributesQueryConfig config,
);