queryRoomMembers abstract method
Query the information of the specified userID in the specified room.
Available since: 2.8.0 and above. Description: This method can query the information of up to ten users in the specified room of the logged-in user. Use cases: When you need to know the user information in the specified room, you can call this interface to obtain the data source. When to call /Trigger: Can be invoked after login. Restrictions: Available after login, unavailable after logout, up to ten users can be queried at one time.
userIDsList of user IDs to query.roomIDThe room ID of the specified room.
Implementation
Future<ZIMRoomMembersQueriedResult> queryRoomMembers(
List<String> userIDs, String roomID);