queryRoomMembersAttributes abstract method
Batch query the room user attributes of the members in the room.
Available since:2.4.0 or later.
Description:Call this API to batch query the room user attributes of the members in the room.
Use cases:Use this interface when you need to specify that you want to query some room users.
Restrictions:The maximum call frequency is 5 times within 30 seconds by default, and the maximum query time is 100 people.
Related callbacks:ZIMRoomMembersAttributesQueriedCallback.
Related APIs: setRoomMembersAttributes、queryRoomMemberAttributesList.
Runtime lifecycle: It is available after logging in and joining the corresponding room, but unavailable after leaving the corresponding room.
userIDsA list of userIDs to query.roomIDRoom ID.
Implementation
Future<ZIMRoomMembersAttributesQueriedResult> queryRoomMembersAttributes(
List<String> userIDs,
String roomID,
);