querySelfUserInfo abstract method
Query user information and user rules.
Available since: 2.15.0 . Description: Query information about the current user and user rules. In offline state, you can query local data. Use cases: If you need to display the user information and rules, you can invoke the query, for example, to enter the personal page of the current user. When to call: Call after login. Restrictions: ZIMSelfUserInfoQueriedCallback、userInfoUpdated、userRuleUpdated
Implementation
Future<ZIMSelfUserInfoQueriedResult> querySelfUserInfo();