queryUsersInfo abstract method
Future<ZIMUsersInfoQueriedResult>
queryUsersInfo(
- List<
String> userIDs, - ZIMUserInfoQueryConfig config
Query user information.
Available since: 2.3.0 or above.
Description: Through this interface, you can query and obtain the corresponding UserInfo by userID.
When to call /Trigger: It is available only after calling create to create the instance and then calling login to login.
Related callbacks: ZIMUsersInfoQueriedCallback.
Usage restrictions: No more than 10 userids can be queried by invoking the interface at a time. If the interface is invoked multiple times within 10 seconds, the total number of userids queried cannot exceed 10.
userIDsuserID list.configQuery user information configuration.
Implementation
Future<ZIMUsersInfoQueriedResult> queryUsersInfo(
List<String> userIDs,
ZIMUserInfoQueryConfig config,
);