sendRoomMessage abstract method
- @Deprecated('This API has been deprecated since 2.4.0, use [sendMessage] instead.')
- ZIMMessage message,
- String toRoomID,
- ZIMMessageSendConfig config
Send room messages.
Available since: 1.1.0 or above
Description: When this function is called, the message will be sent in the room. At the same time, the ZIMMessageSentCallback callback will be received, which can be used to determine whether the message was sent successfully.
Use Cases: This feature is required for scenarios where multiple people in the room are chatting.
@deprecated This API has been deprecated since 2.4.0, use sendMessage instead.
messageThe message to be sent.toRoomIDThe ID of the room which will receive the message.configRelated configuration for sending room messages.
Implementation
@Deprecated(
'This API has been deprecated since 2.4.0, use [sendMessage] instead.')
Future<ZIMMessageSentResult> sendRoomMessage(
ZIMMessage message, String toRoomID, ZIMMessageSendConfig config);