setLogConfig static method
Set log related configuration.
Supported version: 1.1.0 and above.
Detailed description: Set log related configuration, including log path and log size. Since there is a default log path inside the SDK, unless the developer has a strong need to customize the log path, it is generally not recommended that customers set it by themselves.
Defaults:
Android: /storage/Android/data/packageName/files/ZIMLogs
iOS: ~/Library/Caches/ZIMLogs
macOS: (sandbox) ~/Library/Containers/Bundle ID/Data/Library/Caches/ZIMLogs /; (non-sandbox) ~/Library/Caches/ZIMLogs
Windows: C:/Users/Your UserName/AppData/App NameZEGO.SDK/ZIMLogs
When to call: It must be called before create.
Note: If the developer calls after create, the SDK will save this configuration until the next time create takes effect.
Life cycle: Set before calling create, and take effect when calling create. If the developer does not set a new log configuration in the next create, the previous configuration will still take effect.
Platform difference: The default path of different platforms is different, please refer to the default value.
Related reference: For details, please refer to https://doc-zh.zego.im/faq/IM_sdkLog?product=IM&platform=all.
configCustom log configuration
Implementation
static void setLogConfig(ZIMLogConfig config) {
ZIMManager.setLogConfig(config);
}