updateConversationPinnedState abstract method
Future<ZIMConversationPinnedStateUpdatedResult>
updateConversationPinnedState(
- bool isPinned,
- String conversationID,
- ZIMConversationType conversationType
Modify the conversation pinned state.
Available since: 2.8.0 and above.
Description: This method can modify the pinned state of the specified conversation of the logged-in user.
Use cases: You can call this interface when you need to modify the pinned state of a conversation.
When to call /Trigger: Can be invoked after login.
Restrictions: Available after login, unavailable after logout.
Related callbacks: ZIMConversationPinnedStateUpdatedCallback.
isPinnedWhether the conversation is pinned, true is pinned, false is unpinned.conversationIDConversation ID.conversationTypeConversation type.
Implementation
Future<ZIMConversationPinnedStateUpdatedResult> updateConversationPinnedState(
bool isPinned,
String conversationID,
ZIMConversationType conversationType);