updateGroupAlias abstract method
Update the group alias.
Available since: 2.18.0 and above. Description: After a group is created, users can call this method to change the group alias. Use cases: To distinguish different group. When to call: The ZIM instance can be invoked after being created by create and logged in. Related callbacks: Through the callback ZIMGroupAliasUpdatedResult can get the result of the change of group alias.
groupAliasThe new group alias.groupIDThe target group ID.
Implementation
Future<ZIMGroupAliasUpdatedResult> updateGroupAlias(
String groupAlias,
String groupID,
);