updateMessageLocalExtendedData abstract method
Future<ZIMMessageLocalExtendedDataUpdatedResult>
updateMessageLocalExtendedData(
- String localExtendedData,
- ZIMMessage message
Update the local expandable field of the message.
Available since: 2.2.0 or above. Description: After the user logs in, calling this interface allows updating the local expandable field of the message. When to call: After the user is logged in. Privacy statement: Please avoid passing sensitive personal information, including but not limited to phone numbers, ID card numbers, passport numbers, real names, etc. Related callbacks: ZIMMessageLocalExtendedDataUpdatedResult .
localExtendedDataThe expandable message field visible only on this end can store additional information locally and currently has a length limit of 128K. If you have special requirements, please contact ZEGO technical support for configuration.messageMessage body to be updated
Implementation
Future<ZIMMessageLocalExtendedDataUpdatedResult>
updateMessageLocalExtendedData(String localExtendedData, ZIMMessage message);