ZIMAppConfig class
ZIM application configuration, including AppID and AppSign.
Constructors
- ZIMAppConfig({int appID = 0, String appSign = ''})
- ZIMAppConfig.fromMap(Map map)
Properties
- appID ↔ int
-
Description:AppID, please go to the ZEGO official website console to apply for it. Required: Required.
getter/setter pair
- appSign ↔ String
-
Description:AppSign, please go to the ZEGO official website console to apply for it. Required: Required.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited