ZIMAudioMessage class
Audio message object.
Description: Identifies the basic parameters of a message. Caution: If the Type parameter of the base class is Audio during callback, you can force the base class message object to be of this type.
- Inheritance
-
- Object
- ZIMMessage
- ZIMMediaMessage
- ZIMAudioMessage
Constructors
- ZIMAudioMessage(dynamic fileLocalPath, {int audioDuration = 0})
- ZIMAudioMessage.fromMap(Map map)
Properties
- audioDuration ↔ int
-
Detail description: The duration of the audio file. Required: Required by the sender, if not filled, the audio message will fail to be sent When sending local audio messages.
getter/setter pair
- cbInnerID ↔ String
-
getter/setter pairinherited
- conversationID ↔ String
-
Description: Conversation ID. Ids of the same conversation type are unique.
getter/setter pairinherited
- conversationSeq ↔ int
-
Description: Indicates the sequence number of the message in the conversation.
getter/setter pairinherited
- conversationType ↔ ZIMConversationType
-
Description: The type of conversation to which the message belongs.
getter/setter pairinherited
- direction ↔ ZIMMessageDirection
-
Description: Used to describe whether a message is sent or received.
getter/setter pairinherited
- editedTime ↔ int
-
Description: The time of message editing.
getter/setter pairinherited
- editorUserID ↔ String
-
Description: The userID of the message editor.
getter/setter pairinherited
- extendedData ↔ String
-
Description: message extension field Use cases: You can add extended fields to the message and send it to the peer Required: no Caution:the length is 1k, you can contact technical support for configuration Available since: 2.6.0 or higher
getter/setter pairinherited
- fileDownloadUrl ↔ String
-
Detail description: The external download url of the media message is used for the developer to transparently transmit the media file to other users by filling in this URL when the developer uploads the media file to his own server.Required or not: If an external URL is sent, this parameter is mandatory on the sender end.
getter/setter pairinherited
- fileLocalPath ↔ dynamic
-
Detail description: The local path of the media message. Required: If a local file is sent, this parameter must be set by the sender. Otherwise, the message fails to be sent.
getter/setter pairinherited
- fileName ↔ String
-
Detail description: The filename of the media file. Required or not: If you are sending an external URL, you need to fill in this value and include the file extension. If a local file is sent, the value is optional.
getter/setter pairinherited
- fileSize ↔ int
-
Detail description: The size of the media file. Required or not: The sender does not need to fill in, this value is generated by the SDK.
getter/setter pairinherited
- fileUID ↔ String
-
Detail description: The unique ID of the media file. Required or not: The sender does not need to fill in, this value is generated by the SDK.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBroadcastMessage ↔ bool
-
Description: Whether the message is pushed by all employees. Required: Internal assignment.
getter/setter pairinherited
- isGroupTargetedMessage ↔ bool
-
Indicates whether the message is a group-targeted message.
getter/setter pairinherited
- isMentionAll ↔ bool
-
Description: Whether to mention everyone. It can be presented as "@Everyone". Use cases: For example, it can be used in groups or rooms. Required: No. Default value: false. Recommended value: Set to true if you need to mention everyone. Caution: This value does not add the "@Everyone" to the message text. Developers need to implement it themselves. Available since: 2.14.0 or above
getter/setter pairinherited
- isServerMessage ↔ bool
-
getter/setter pairinherited
- isUserInserted ↔ bool
-
Detail description: Describes whether the message is a message inserted by the developer through
insertMessageToLocalDB.Default: false.getter/setter pairinherited - localExtendedData ↔ String
-
Description: The expandable message field visible only on this end can store additional information locally, Through
updateMessageLocalExtendedDatachange and currently has a length limit of 128K. If you have special requirements, please contact ZEGO technical support for configuration.getter/setter pairinherited - localMessageID ↔ dynamic
-
Description: SDK locally generated MessageID, developers do not need to pay attention to.
getter/setter pairinherited
-
mentionedUserIDs
↔ List<
String> -
Description: Whether to mention everyone. It can be presented as "@User". Use cases: For example, it can be used in sending messages. Required: No. Caution: This value does not add the "@User" to the message text. Developers need to implement it themselves. Available since: 2.14.0 or above
getter/setter pairinherited
- messageID ↔ dynamic
-
Description: The unique ID that identifies this message.Use cases: Can be used to index other messages.Caution: When the developer actively creates a message, there is no need to modify this parameter.This parameter only has a value during callback.
getter/setter pairinherited
- messageSeq ↔ int
-
Description: The sequence number of the message.
getter/setter pairinherited
- orderKey ↔ int
-
Description:The larger the orderKey, the newer the message, and can be used for ordering messages.
getter/setter pairinherited
- pinnedTime ↔ int
-
Description: The time of message pinning.
getter/setter pairinherited
- pinnedUserID ↔ String
-
Description: The userID of the message pinner.
getter/setter pairinherited
-
reactions
↔ List<
ZIMMessageReaction> -
Description: Message statement list, which can carry data strongly related to users such as emoji expressions and voting information.
getter/setter pairinherited
- receiptStatus ↔ ZIMMessageReceiptStatus
-
Detailed Description: Describe the receipt status of the messageBusiness scenario: used to determine the status of the current message in the receipt message
getter/setter pairinherited
- repliedInfo ↔ ZIMMessageRepliedInfo?
-
Description: Message reply information.
getter/setter pairinherited
- rootRepliedCount ↔ int
-
Description: Root replied count.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- senderUserID ↔ String
-
Description:Displays the userID of the sender of this message.
getter/setter pairinherited
- sentStatus ↔ ZIMMessageSentStatus
-
Description: Describes the sending status of a message.
getter/setter pairinherited
- timestamp ↔ int
-
Description: Identifies the sending time of a messageUse cases: Used to present the sending time of a message, and can be used for message sorting.Caution: This is a standard UNIX timestamp, in milliseconds.
getter/setter pairinherited
- type ↔ ZIMMessageType
-
Identifies the type of this message.
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited