ZIMCallInvitationCreatedInfo class
todo
todo
Constructors
-
ZIMCallInvitationCreatedInfo({ZIMCallInvitationMode mode = ZIMCallInvitationMode.unknown, String caller = '', String extendedData = '', int timeout = 0, int createTime = 0, List<
ZIMCallUserInfo> ? callUserList}) - ZIMCallInvitationCreatedInfo.fromMap(Map map)
Properties
- caller ↔ String
-
getter/setter pair
-
callUserList
↔ List<
ZIMCallUserInfo> -
getter/setter pair
- createTime ↔ int
-
getter/setter pair
- extendedData ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode ↔ ZIMCallInvitationMode
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited