ZIMConversation class
Session specific content.
Description: The specific content of the session.
- Implementers
Constructors
-
ZIMConversation({String conversationID = '', ZIMConversationType type = ZIMConversationType.unknown, String conversationName = '', String conversationAvatarUrl = '', String conversationAlias = '', ZIMConversationNotificationStatus notificationStatus = ZIMConversationNotificationStatus.notify, int unreadMessageCount = 0, ZIMMessage? lastMessage, int orderKey = 0, bool isPinned = false, int pinnedTime = 0, List<
ZIMMessageMentionedInfo> ? mentionedInfoList, String draft = '', List<int> ? marks, int readMessageSeq = 0, bool isConversationDisabled = false, int selfMutedExpiredTime = 0, int messageDestructDuration = 0}) - ZIMConversation.fromMap(Map map)
Properties
- conversationAlias ↔ String
-
After the friend remarks are set through
updateFriendAlias, this parameter is changed for each chat conversation. After setting a group alias byupdateGroupAlias, the corresponding group chat conversation's parameter will be modified synchronously.getter/setter pair - conversationAvatarUrl ↔ String
-
Conversation avatar URL. The peer-to-peer conversation avatar URL is the same as the user avatar URL, and the group conversation avatar URL is the same as the group avatar URL.
getter/setter pair
- conversationID ↔ String
-
Conversation ID.
getter/setter pair
- conversationName ↔ String
-
conversationName is the same as the groupName/userName value corresponding to the session.
getter/setter pair
- draft ↔ String
-
Conversation draft, when draft set conversation will carry this parameter.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConversationDisabled ↔ bool
-
Whether the conversation is unavailable.
getter/setter pair
- isPinned ↔ bool
-
Whether the conversation is pinned.
getter/setter pair
- lastMessage ↔ ZIMMessage?
-
The last message in the conversation.
getter/setter pair
-
marks
↔ List<
int> -
Describes all the existing marks for the conversation.
getter/setter pair
-
mentionedInfoList
↔ List<
ZIMMessageMentionedInfo> -
When reminded in a message or reminded to everyone in a conversation, this array will record the reminders.
getter/setter pair
- messageDestructDuration ↔ int
-
The timed message self-destruction duration for the conversation.
getter/setter pair
- notificationStatus ↔ ZIMConversationNotificationStatus
-
Conversation notification status.
getter/setter pair
- orderKey ↔ int
-
OrderKey is used to describe the order of messages in the session. The larger orderKey is, the newer it is.
getter/setter pair
- pinnedTime ↔ int
-
Description: The timestamp of conversation pinned.
getter/setter pair
- readMessageSeq ↔ int
-
Conversation read message sequence number.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfMutedExpiredTime ↔ int
-
The expiration timestamp of the self-mute for this conversation.
getter/setter pair
- type ↔ ZIMConversationType
-
Conversation type.
getter/setter pair
- unreadMessageCount ↔ int
-
Unread message count of the conversation.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited