conversationAvatarUrl property
Conversation avatar URL. The peer-to-peer conversation avatar URL is the same as the user avatar URL, and the group conversation avatar URL is the same as the group avatar URL.
Implementation
String conversationAvatarUrl;