onBlacklistChanged property
void Function(ZIM zim, List<ZIMUserInfo> userList, ZIMBlacklistChangeAction action)?
onBlacklistChanged
getter/setter pair
Event callback when the blacklist changes.
Available since: 2.13.0 and above.
Description: This callback is triggered when the current user's blacklist changes.
Triggered when: This callback is triggered for the current user and all online devices when the current user adds or removes a user from the blacklist.
Related APIs: addUsersToBlacklist, removeUsersFromBlacklist.
zimZIM instance.userListBlacklist user list.actionBlacklist change operation.
Implementation
static void Function(
ZIM zim,
List<ZIMUserInfo> userList,
ZIMBlacklistChangeAction action,
)?
onBlacklistChanged;