onCallInvitationReceived property
void Function(ZIM zim, ZIMCallInvitationReceivedInfo info, String callID)?
onCallInvitationReceived
getter/setter pair
Event callback when the call invitation is received.
Supported versions: 2.0.0 and above.
Business scenario: The invitee will call this callback after the inviter sends a call invitation.
When to call: After creating a ZIM instance through create.
Note: If the user is not in the invitation list or not online, this callback will not be called.
Related interface: callInvite.
zimZIM instance.infoCall invitation information.callIDCall ID.
Implementation
static void Function(
ZIM zim,
ZIMCallInvitationReceivedInfo info,
String callID,
)? onCallInvitationReceived;