onCallInvitationRejected property
- @Deprecated('Deprecated since 2.9.0, pleace use [onCallUserStateChanged] instead.')
getter/setter pair
Event callback when the call invitation is rejected.
Supported versions: 2.0.0 and above.
Detail description: After the invitee accepts the call invitation, this callback will be received when the inviter is online.
Business scenario: The inviter will receive this callback after the inviter accepts the call invitation.
When to call: After creating a ZIM instance through create.
Note: This callback will not be called if the user is not online.
Related interface: callAccept.
@deprecated Deprecated since 2.9.0, pleace use onCallUserStateChanged instead.
zimZIM instance.infotodocallIDCall ID.
Implementation
@Deprecated(
'Deprecated since 2.9.0, pleace use [onCallUserStateChanged] instead.')
static void Function(
ZIM zim, ZIMCallInvitationRejectedInfo info, String callID)?
onCallInvitationRejected;