onCallInviteesAnsweredTimeout property
- @Deprecated('Deprecated since 2.9.0, pleace use [onCallUserStateChanged] instead.')
getter/setter pair
Event callback when the call invitation invitee times out.
Supported versions: 2.0.0 and above.
Detail description: When the call invitation times out, the invitee does not respond, and the inviter will receive a callback.
Business scenario: The invitee does not respond before the timeout period, and the inviter will receive this callback.
When to call: After creating a ZIM instance through create.
Note: If the user is not the inviter who initiated this call invitation or is not online, the callback will not be received.
Related interfaces: callInvite, callAccept, callReject.
- zim ZIM instance.
- invitees Timeout invitee ID.
- callID The number of invitees that have timed out.
@deprecated Deprecated since 2.9.0, pleace use onCallUserStateChanged instead.
zimZIM instance.inviteesInvitee ID.callIDCall ID.
Implementation
@Deprecated(
'Deprecated since 2.9.0, pleace use [onCallUserStateChanged] instead.')
static void Function(ZIM zim, List<String> invitees, String callID)?
onCallInviteesAnsweredTimeout;