onConnectionStateChanged property

void Function(ZIM zim, ZIMConnectionState state, ZIMConnectionEvent event, Map extendedData)? onConnectionStateChanged
getter/setter pair

The event callback when the connection state changes.

  • zim zim ZIM instance.
  • state The current connection state after changed.
  • event The event that caused the connection state to change.
  • extendedData Extra information when the event occurs, a standard JSON string.

Implementation

static void Function(ZIM zim, ZIMConnectionState state,
    ZIMConnectionEvent event, Map extendedData)? onConnectionStateChanged;