onConnectionStateChanged property
void Function(ZIM zim, ZIMConnectionState state, ZIMConnectionEvent event, Map extendedData)?
onConnectionStateChanged
getter/setter pair
The event callback when the connection state changes.
zimzim ZIM instance.stateThe current connection state after changed.eventThe event that caused the connection state to change.extendedDataExtra information when the event occurs, a standard JSON string.
Implementation
static void Function(ZIM zim, ZIMConnectionState state,
ZIMConnectionEvent event, Map extendedData)? onConnectionStateChanged;