onGroupAttributesUpdated property
void Function(ZIM zim, List<ZIMGroupAttributesUpdateInfo> infoList, ZIMGroupOperatedInfo operatedInfo, String groupID)?
onGroupAttributesUpdated
getter/setter pair
Event callback when the group attributes change.
Group attributes update notification callback.
Description: Group attribute change notification callback.
Use cases: When group attributes are changed, you need to synchronize the latest group attributes.
When to call /Trigger: Triggered when group properties are set, updated, or deleted.
Impacts on other APIs: setGroupAttributes updates group attributes. deleteGroupAttributes, delete the group attribute.
zimZIM instance.infoListGroup attribute change information.operatedInfoGroup operation information.groupIDGroup ID.
Implementation
static void Function(
ZIM zim,
List<ZIMGroupAttributesUpdateInfo> infoList,
ZIMGroupOperatedInfo operatedInfo,
String groupID)? onGroupAttributesUpdated;