onMessageRevokeReceived property
void Function(ZIM zim, List<ZIMRevokeMessage> messageList)?
onMessageRevokeReceived
getter/setter pair
Received notification callback when some one else sends a message and then revoke a message sent by themselves.
Available since: 2.5.0 and above.
Description: This callback is received when some one else sends a message and then revoke.
When to call /Trigger: This callback occurs when a ZIM instance is created with create and the other user revoke a message.
Related APIs: You can revoke message to other members via revokeMessage.
zimZIM instance.messageListList of message revoke information.
Implementation
static void Function(ZIM zim, List<ZIMRevokeMessage> messageList)?
onMessageRevokeReceived;