onRoomStateChanged property
void Function(ZIM zim, ZIMRoomState state, ZIMRoomEvent event, Map extendedData, String roomID)?
onRoomStateChanged
getter/setter pair
The event callback when the room connection status changes.
Description:event callback when the room connection status changes.
When to call::After creating a ZIM instance through create, you can call this interface.
Related APIs:through onTokenWillExpire, the callback will be received when the token is about to expire.
zimZIM instance.stateRoom state.eventRoom event.extendedDataExtended data.roomIDRoom ID.
Implementation
static void Function(ZIM zim, ZIMRoomState state, ZIMRoomEvent event,
Map extendedData, String roomID)? onRoomStateChanged;