ZIMGroupFullInfo class
Group full information
todo
Constructors
-
ZIMGroupFullInfo({required ZIMGroupInfo baseInfo, required String groupNotice, required Map<
String, String> groupAttributes, required String groupAlias, required ZIMGroupMessageNotificationStatus notificationStatus, required ZIMGroupMuteInfo mutedInfo, required int createTime, required int maxMemberCount, required ZIMGroupVerifyInfo verifyInfo}) - ZIMGroupFullInfo.fromMap(Map map)
Properties
- baseInfo ↔ ZIMGroupInfo
-
getter/setter pair
- createTime ↔ int
-
getter/setter pair
- groupAlias ↔ String
-
getter/setter pair
-
groupAttributes
↔ Map<
String, String> -
getter/setter pair
- groupNotice ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxMemberCount ↔ int
-
getter/setter pair
- mutedInfo ↔ ZIMGroupMuteInfo
-
getter/setter pair
- notificationStatus ↔ ZIMGroupMessageNotificationStatus
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verifyInfo ↔ ZIMGroupVerifyInfo
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited