ZIMGroupMembersMutedResult class
todo
- groupID Group ID.
- isMute Whether to mute.
- duration Mute duration.
- mutedMemberIDs List of muted member IDs.
- errorUserList List of user information that failed to be muted.
- Available extensions
Constructors
-
ZIMGroupMembersMutedResult({required String groupID, required bool isMute, required int duration, required List<
String> mutedMemberIDs, required List<ZIMErrorUserInfo> errorUserList}) - ZIMGroupMembersMutedResult.fromMap(Map map)
Properties
- duration ↔ int
-
Mute duration.
getter/setter pair
-
errorUserList
↔ List<
ZIMErrorUserInfo> -
List of user information that failed to be muted.
getter/setter pair
- groupID ↔ String
-
Group ID.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isMute ↔ bool
-
Whether to mute.
getter/setter pair
-
mutedMemberIDs
↔ List<
String> -
List of muted member IDs.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited