ZIMGroupsSearchedResult class
todo
- groupSearchInfoList Group search information list.
- nextFlag Used to query the next page. The current value returns 0, which means that the list has been pulled out.
- Available extensions
Constructors
-
ZIMGroupsSearchedResult({required List<
ZIMGroupSearchInfo> groupSearchInfoList, required int nextFlag}) - ZIMGroupsSearchedResult.fromMap(Map map)
Properties
-
groupSearchInfoList
↔ List<
ZIMGroupSearchInfo> -
Group search information list.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextFlag ↔ int
-
Used to query the next page. The current value returns 0, which means that the list has been pulled out.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited