ZIMMessageDeleteConfig class
Delete message configuration.
Description: Delete configurations related to messages.
Constructors
- ZIMMessageDeleteConfig({bool isAlsoDeleteServerMessage = false})
- ZIMMessageDeleteConfig.fromMap(Map map)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAlsoDeleteServerMessage ↔ bool
-
Description: Whether to remove flags for server messages. Required: not required. Default value: false.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited