ZIMMessageMentionedInfo class
message mention information.
message mention information.
Constructors
- ZIMMessageMentionedInfo({required dynamic messageID, required int messageSeq, required String fromUserID, required ZIMMessageMentionedType type})
- ZIMMessageMentionedInfo.fromMap(Map map)
Properties
- fromUserID ↔ String
-
Description: From which user. Required: Developers do not need to fill in.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageID ↔ dynamic
-
Description: Message ID, used to match the notification information to which message it belongs toRequired or not: Developers do not need to fill in.
getter/setter pair
- messageSeq ↔ int
-
Description: Message sequence number, used to match the notification information to which message it belongs toRequired or not: Developers do not need to fill in.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ ZIMMessageMentionedType
-
Details Description: Type of notification, used to distinguish between reminding oneself and reminding everyone. Required: Developers do not need to fill in.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited