ZIMMessageRepliedInfo class
The reply message refers to the information of the source message.
Constructors
- ZIMMessageRepliedInfo({required ZIMMessageRepliedInfoState state, required ZIMMessageLiteInfo messageInfo, required String senderUserID, required int sentTime, required dynamic messageID, required int messageSeq})
- ZIMMessageRepliedInfo.fromMap(Map map)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageID ↔ dynamic
-
Description: ID of the replied message.
getter/setter pair
- messageInfo ↔ ZIMMessageLiteInfo
-
Description: Replied message lite information.
getter/setter pair
- messageSeq ↔ int
-
Description: Sequence number of the replied message.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- senderUserID ↔ String
-
Description: Sender user ID of the replied message.
getter/setter pair
- sentTime ↔ int
-
Description: Sent time of the replied message.
getter/setter pair
- state ↔ ZIMMessageRepliedInfoState
-
Description: Message replied state.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited