ZIMMessageSendConfig class
Configurations related to sending messages.
Description: Configurations related to sending messages.
Constructors
- ZIMMessageSendConfig({ZIMPushConfig? pushConfig, ZIMMessagePriority priority = ZIMMessagePriority.low, bool hasReceipt = false, bool isNotifyMentionedUsers = true, bool isRetrySend = false, bool disableUnreadMessageCount = false, bool isAllowMultipleMessagePartialFailed = false})
- ZIMMessageSendConfig.fromMap(Map map)
Properties
- disableUnreadMessageCount ↔ bool
-
When sending messages that would otherwise affect the other party's unread count, should they no longer be counted as unread by the other party? Whether required: Not required. Default value: false.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasReceipt ↔ bool
-
Detailed description: When sending a message, whether the message has a receipt.Business scenario: use when you need to bring a receipt for a message.Required: not required.Default value: false.
getter/setter pair
- isAllowMultipleMessagePartialFailed ↔ bool
-
Whether to allow some sub-messages to fail to send when sending a multiple message. Whether required: Not required. Default value: false.
getter/setter pair
- isNotifyMentionedUsers ↔ bool
-
todo
getter/setter pair
- isRetrySend ↔ bool
-
todo
getter/setter pair
- priority ↔ ZIMMessagePriority
-
Enumeration value used to set message priority. Required: Must mandatory.
getter/setter pair
- pushConfig ↔ ZIMPushConfig?
-
Description: Configures the offline push function, If Android or iOS platform is integrated, it is strongly recommended to configure this. Required: Not mandatory.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited