ZIMMessageSendNotification class
The notification callback when the message is sent, you can get the relevant information before the message object is sent through this notification
Detailed description: Through this notification, developers can obtain relevant information before the message object is sent, such as localMessageID, etc. Business scenario: When developers need to record and cache relevant information before sending a message, they can obtain it by listening to the notification. Note: If no monitoring is required, it can be passed null.
Constructors
- ZIMMessageSendNotification({ZIMMessageAttachedCallback? onMessageAttached, ZIMMediaUploadingProgress? onMediaUploadingProgress, ZIMMultipleMediaUploadingProgress? onMultipleMediaUploadingProgress})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onMediaUploadingProgress ↔ ZIMMediaUploadingProgress?
-
Description: Media file upload progress.
getter/setter pair
- onMessageAttached ↔ ZIMMessageAttachedCallback?
-
Detail description: After the message falls into the local DB, the notification will be called back before the message is sent to the server. Business scenario: This interface can be used when the developer needs to obtain the relevant information in the message in advance before sending the message. Required: not required. If no monitoring is required, it can be passed empty. Default: empty.
getter/setter pair
- onMultipleMediaUploadingProgress ↔ ZIMMultipleMediaUploadingProgress?
-
Description: Multiple media file upload progress.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited