ZIMOfflinePushPrivateMessageTemplate class
The private message template is currently only applicable to the OPPO manufacturer.
The private message template is currently only applicable to the OPPO manufacturer.
Constructors
- ZIMOfflinePushPrivateMessageTemplate({String templateID = '', String titleParameters = '', String contentParameters = ''})
- ZIMOfflinePushPrivateMessageTemplate.fromMap(Map map)
Properties
- contentParameters ↔ String
-
Description: To replace the content of the preset fields in the template, a json string needs to be filled in, such as "{"city":" Shenzhen "}".
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- templateID ↔ String
-
Description: The private message template ID is currently only applicable to OPPO manufacturers. Please fill in the template ID preset in the OPPO Open Platform console.
getter/setter pair
- titleParameters ↔ String
-
Description: To replace the content of the preset title field in the template, a json string needs to be filled in, such as "{"user_name":" Li Hua "}".
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited