ZIMPushConfig class
Description: Offline push configuration.
Details: Configuration before sending offline push.
Constructors
- ZIMPushConfig({String title = '', String content = '', String payload = '', String resourcesID = '', bool enableBadge = false, int badgeIncrement = 0, ZIMVoIPConfig? voIPConfig, ZIMOfflinePushPrivateMessageTemplate? privateMessageTemplate})
- ZIMPushConfig.fromMap(Map map)
Properties
- badgeIncrement ↔ int
-
Description: The incremental index number carried by the push.
getter/setter pair
- content ↔ String
-
Description: Used to set offline push content.Required: Not required.
getter/setter pair
- enableBadge ↔ bool
-
Description: Push whether to carry corner information switch.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- payload ↔ String
-
Description: This parameter is used to set the pass-through field of offline push.Required: Not required.
getter/setter pair
- privateMessageTemplate ↔ ZIMOfflinePushPrivateMessageTemplate?
-
Description: If you use OPPO Push, you can carry the push template through this field.
getter/setter pair
- resourcesID ↔ String
-
Description: Offline push advanced configuration for mapping console Settings, with the maximum of 32 characters and defined by yourself.Required: Not required.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title ↔ String
-
Description: Used to set the push title.Required: Not required.
getter/setter pair
- voIPConfig ↔ ZIMVoIPConfig?
-
Description: If you use Flutter, RN ZPNs, offline push receiving device has iOS and uses VoIP push type, you can customize some VoIP options with this parameter.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited