ZIMRoomEvent enum
- Inheritance
- Available extensions
Values
- success → const ZIMRoomEvent
- interrupted → const ZIMRoomEvent
- disconnected → const ZIMRoomEvent
- roomNotExist → const ZIMRoomEvent
- activeCreate → const ZIMRoomEvent
- createFailed → const ZIMRoomEvent
- activeEnter → const ZIMRoomEvent
- enterFailed → const ZIMRoomEvent
- kickedOut → const ZIMRoomEvent
- connectTimeout → const ZIMRoomEvent
- kickedOutByOtherDevice → const ZIMRoomEvent
- activeSwitch → const ZIMRoomEvent
- switchFailed → const ZIMRoomEvent
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
Available on ZIMRoomEvent, provided by the ZIMRoomEventExtension extension
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ZIMRoomEvent> - A constant List of the values in this enum, in order of their declaration.