ZIMRoomInfo class
Room information object.
Description: Identifies a unique room.
Constructors
- ZIMRoomInfo({String roomID = '', String roomName = ''})
- ZIMRoomInfo.fromMap(Map map)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- roomID ↔ String
-
Room ID. a string with a maximum length of 128 bytes. It is customized by the developer and supports only digits, English characters,
, and '!', '#', '$', '%', '&', '(', ')', '+', '-', ':', ';', '<', '=', '.', '>', '?', '@', ''.', '', '^', '_', '{', '}', '|', 'getter/setter pair - roomName ↔ String
-
Room name, It is customized by the developer .a string with a maximum length of 64 bytes or less.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited