ZIMRoomMemberAttributesOperatedInfo class
Room user attribute operation information.
Description: Detail description: room user attribute operation information, including attributes of successful operation and keys of failure.
Constructors
-
ZIMRoomMemberAttributesOperatedInfo({ZIMRoomMemberAttributesInfo? attributesInfo, List<
String> ? errorKeys}) - ZIMRoomMemberAttributesOperatedInfo.fromMap(Map map)
Properties
- attributesInfo ↔ ZIMRoomMemberAttributesInfo
-
Detailed description: room user attribute information.
getter/setter pair
-
errorKeys
↔ List<
String> -
Detail description: The key of the room user attribute operation failure.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited