ZIMRoomState enum
Used to indicate the user's connection status to the room.
- Inheritance
- Available extensions
Values
- disconnected → const ZIMRoomState
-
Indicates that the connection to the room is interrupted, and the
createRoom,joinRoom, andenterRoomfails. If the network is disconnected for a long time, the heartbeat of the room times out, the background notifies the user that he has been kicked out of the room, or the logout will throw this status. - connecting → const ZIMRoomState
-
connecting indicates that the connection between a room and a room is in the connecting state. When the create, join, or enter room connection is not returned, this state is thrown when the network is disconnected.
- connected → const ZIMRoomState
-
connected indicates that the device is properly connected to the room. If create, join, or enter room succeeds, the state will be thrown if the network is disconnected and the room heartbeat does not time out.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
Available on ZIMRoomState, provided by the ZIMRoomStateExtension extension
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ZIMRoomState> - A constant List of the values in this enum, in order of their declaration.