ZIMVoIPConfig class
Provides information about the iOS VoIP offline push.
Provides information about the iOS VoIP offline push.
Constructors
- ZIMVoIPConfig({ZIMCXHandleType iOSVoIPHandleType = ZIMCXHandleType.generic, String iOSVoIPHandleValue = '', bool iOSVoIPHasVideo = false})
- ZIMVoIPConfig.fromMap(Map map)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- iOSVoIPHandleType ↔ ZIMCXHandleType
-
Description: The type of contact information for the VoIP caller, by default, is generic.
getter/setter pair
- iOSVoIPHandleValue ↔ String
-
Description: The contact information of the VoIP caller. It is related to iOSVoIPHandleType. When iOSVoIPHandleType is PhoneNumber, the Value is a sequence of digits; when iOSVoIPHandleType is EmailAddress, the Value is an email address; when the contact information is of other types, the Value typically follows some domain-specific format, such as a username, numeric ID, or URL.
getter/setter pair
- iOSVoIPHasVideo ↔ bool
-
Description: Video call or not. The default value is audio
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited